      SUBROUTINE SIPC_Init_Model (cdjobnam, cdmodnam, kmodel, kinfo)
C****
C               *********************
C               * OASIS TOY ROUTINE *
C               * ----------------- *
C               *********************
C
C**** *SIPC_Init_Model* 
C
C     Purpose:
C     -------
C     - Attaches toy model to shared memory segment pool used to exchange 
C       initial infos.
C
C**   Interface:
C     ---------
C       *CALL*  *SIPC_Init_Model(cdjobnam, cdmodnam, 1, kinfo)*
C
C     Input:
C     -----
C                cdjobnam : experiment name (char string)
C                cdmodnam : remote models names (char string)
C                1        : kmodel=1 remote model (integer)
C
C     Output:
C     ------
C                kinfo    : error status
C
C     Workspace:
C     ---------
C     None
C
C     Externals:
C     ---------    
C
C     Reference:
C     ---------
C
C     History:
C     -------
C       Programmer     Date      Description
C       ----------     ----      -----------  
C       S. Valcke      97/08/12  created
C
C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C
C* ---------------- COMMON and PARAMETER declarations ---------------------------
C
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
C
C* ---------------------------- Argument declarations -------------------
C
      CHARACTER*6 cdmodnam
      CHARACTER*3 cdjobnam
      INTEGER kmodel, kinfo
C
C* ---------------------------- Local declarations ----------------------
C
      INTEGER ic, icumul, imrc, jm
      CHARACTER*7 clmodnamr, clmodnamw
      LOGICAL lldummy
C
C* ---------------------------- Poema verses ----------------------------
C
C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C
C for debuging
C
C      CALL SVIPC_debug(1)
C
C*    1. Initializations
C        ---------------
C
      WRITE (*,*) ' '
      WRITE (*,*) ' Entering  ROUTINE SIPC_Init_Model'
      WRITE (*,*) ' from model ', cdmodnam
      WRITE (*,*) ' '
C
C* Zeroes error codes
C
      icumul = 0
C
C*   2. IF dummy FILE 'DUMMY_file' exists, attach to the shared-memory pool 
C       used to communicate initial infos between coupler and remote model
C       ------------------------------------------------------------------
C
      kinfo = 0
      lldummy = .FALSE.
      ic = 0
      DO WHILE ( .not. lldummy )
        INQUIRE(FILE='DUMMY_SIPC', EXIST=lldummy)
        CALL sleep(2)
        ic=ic+1
        IF(ic .EQ. jptest) THEN
            lldummy = .TRUE.
            kinfo = -1
        ENDIF
      END DO
C
      IF (kinfo .EQ. 0) THEN
          DO 310 jm = 1, kmodel
C
C Attach to pool for infos written by the model, READ by oasis. 
C
            imrc = 0
            clmodnamr = cdmodnam//'R'
            CALL svipc_open(mpoolinitr, clmodnamr, 0, imrc)
C
C* Find error if any
C
            IF (imrc .LT. 0) THEN
                WRITE (*,*) 'Problem in attaching to the pool',
     $              clmodnamr 
                icumul = icumul + 1
            ELSE
                WRITE (*,*) 'Pool for initial infos read by oasis'
                WRITE (*,*) 'is attached to ', cdmodnam
C
            ENDIF
C
C Attach to pool of one segment for infos READ by model, written by oasis
C
            imrc = 0
            clmodnamw = cdmodnam//'W'
            CALL svipc_open(mpoolinitw, clmodnamw, 0, imrc)
C
C* Find error if any
C
            IF (imrc .LT. 0) THEN
                WRITE (*,*) 'Problem in attaching to the pool ',
     $              clmodnamw 
                icumul = icumul + 1
            ELSE
                WRITE (*,*) 'Pool for initial infos written by oasis'
                WRITE (*,*) 'is attached to ',  cdmodnam
            ENDIF
C
 310        CONTINUE
        ENDIF
C
C* Change error status if any error occurs
C
      IF (icumul .NE. 0) kinfo = icumul
      IF (kinfo .LT. 0) kinfo = 2
C
C
C*    4. End of routine
C        --------------
C
      WRITE (*,*) ' '
      WRITE (*,*) 
     $    '          --------- End of routine SIPC_Init_Model ---------'
      RETURN
      END
