      SUBROUTINE SIPC_Read_Model (kindex, kdim, cdmodinf, cdjobnam_r, 
     $                             kinfos, pinp_field )
C****
C                     ***************
C                     * TOY ROUTINE * 
C                     * ----------- *
C                     ***************
C
C**** *SIPC_Read_Model*  
C
C     Purpose:
C     -------
C     READ toy model input field and infos from field-specific pool
       
C
C**   Interface:
C     ---------
C       *CALL*  *SIPC_Read_Model (kindex, kdim, cdjobnam_r, kinfos, pinp_field)
C
C     Input:
C     -----
C          kindex : index of field to be read in total number of input fields
C          kdim   : dimension of field to be read 
C          cdmodinf: define IF header must be encapsulated 
C                    within the field brick
C
C     Output:
C     ------
C          cdjobnam_r   :  Experiment name (character)
C          kinfos(1)    :  Initial date (integer)
C          kinfos(2)    :  Iteration number (integer)
C          kinfos(3)    :  Time since start (integer)
C          pinp_field   :  Field to be read
C
C     Workspace:
C     ---------
C     None
C
C     ---------
C     SVIPC_Read_Model
C
C     Reference:
C     ---------
C    
C
C     History:
C     -------
C       Version   Programmer     Date      Description
C       -------   ----------     ----      -----------  
C       2.2       S. Valcke      97/08/25  created
C
C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
C* ---------------------------- Argument declarations -------------------
C
      CHARACTER*3 cdjobnam_r
      CHARACTER*3 cdmodinf
      INTEGER kinfos(3), kdim, kindex
      REAL pinp_field(kdim)
C
C* ---------------------------- INCLUDE files --------------------------
C
C
C* ---------------------------- Local declarations ---------------------
      INTEGER isizeinp, imrc
C* ---------------------------- Poema verses ----------------------------
C
C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C
C*    1. Initializations
C        ---------------
C
      WRITE (*,*) ' '
      WRITE (*,*) 
     $    '           ROUTINE SIPC_Read_Model '
      WRITE (*,*) 
     $    '           ***********************'
      WRITE (*,*) ' '
C
C*    2. Read encapsulated infos in field-specific shared memory pool
C        (experiment name, initial date, time since start, iteration number)
C        -------------------------------------------------------------------
C
      imrc = 0
      IF(cdmodinf.eq.'YES') then
          isizeinp = 3*jpbytecha
          CALL SVIPC_read(mpoolread(kindex), cdjobnam_r, isizeinp, imrc)
          isizeinp = 3*jpbyteint
          CALL SVIPC_read(mpoolread(kindex), kinfos, isizeinp, imrc)
C
C*        Find error if any
C
          IF (imrc .LT. 0) THEN
              WRITE(*,*)
     $            'Problem in reading encapsulated infos for field',
     $            kindex 
              CALL ABORT('STOP in SIPC_Read_Model')
          ENDIF
      ENDIF
C
C*    3. Read field in field-specific shared memory pool
C        -----------------------------------------------
      isizeinp = kdim*jpbyterea
          WRITE(numout,*) 'mpoolread(kindex)', mpoolread(kindex), kindex
          call flush(numout)
      CALL SVIPC_read(mpoolread(kindex), pinp_field, isizeinp, imrc)
C
C
C*    Find error and STOP if any
C
      IF (imrc .LT. 0) THEN
          WRITE(*,*) 'Problem in reading in the SHM pool for field',
     $        kindex 
          CALL ABORT('STOP in SIPC_Read_Model')
      ENDIF
C
C*    4. End of routine
C        --------------
C
      WRITE (*,*) ' '
      WRITE (*,*)' --------- End of routine SIPC_Read_model ---------'
C
      RETURN
      END
