      SUBROUTINE SIPC_Write_Model (kindex, kdim, cdmodinf, cdjobnam, 
     $                             kinfos, pout_field)
C****
C                     ***************
C                     * TOY ROUTINE * 
C                     * ----------- *
C                     ***************
C
C**** *SIPC_Write_Model*  
C
C     Purpose:
C     -------
C     Write toy model output field and infos to field-specific pool
       
C
C**   Interface:
C     ---------
C       *CALL*  *SIPC_Write_Model (kindex, kdim, cdjobnam, kinfos, pout_field)
C
C     Input:
C     -----
C        kindex : index of field to be written in total number of output fields
C        kdim   : dimension of field to be written 
C        cdmodinf: define IF header must be encapsulated 
C                    within the field brick
C
C     Output:
C     ------
C        cdjobnam     :  Experiment name (character)
C        kinfos(1)    :  Initial date (integer)
C        kinfos(2)    :  Iteration number (integer)
C        kinfos(3)    :  Time since start (integer)
C        pout_field   :  Field to be written
C
C     Workspace:
C     ---------
C     None
C
C     Externals:
C     ---------
C     SVIPC_Write_Model
C
C     Reference:
C     ---------
C    
C
C     History:
C     -------
C       Version   Programmer     Date      Description
C       -------   ----------     ----      -----------  
C       2.2       S. Valcke      97/08/25  created
C
C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
C* ---------------------------- Argument declarations -------------------
C
      CHARACTER*3 cdjobnam
      CHARACTER*3 cdmodinf
      INTEGER kinfos(3), kdim, kindex
      REAL pout_field(kdim)
C
C* ---------------------------- INCLUDE files --------------------------
C
C
C* ---------------------------- Local declarations ---------------------
      INTEGER isizeout, imrc
C* ---------------------------- Poema verses ----------------------------
C
C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
C
C*    1. Initializations
C        ---------------
C
      WRITE (*,*) ' '
      WRITE (*,*) 
     $    '           ROUTINE SIPC_Write_Model '
      WRITE (*,*) 
     $    '           *******************     *******'
      WRITE (*,*) ' '
C
C*    2. Write encapsulated infos in field-specific shared memory pool
C        (experiment name, initial date, time since start, iteration number)
C        -------------------------------------------------------------------
C
      imrc = 0
      IF(cdmodinf.eq.'YES') then
          isizeout = 3*jpbytecha
          CALL SVIPC_write(mpoolwrit(kindex), cdjobnam, isizeout, imrc)
          isizeout = 3*jpbyteint
          CALL SVIPC_write(mpoolwrit(kindex), kinfos, isizeout, imrc)
C
C*        Find error if any
C
          IF (imrc .LT. 0) THEN
              WRITE(*,*)
     $            'Problem in writing encapsulated infos for field',
     $            kindex 
              CALL ABORT('STOP in SIPC_Write_Model')
          ENDIF
      ENDIF
C
C*    3. Write field in field-specific shared memory pool
C        -----------------------------------------------
      isizeout = kdim*jpbyterea
      CALL SVIPC_write(mpoolwrit(kindex), pout_field, isizeout, imrc)
C
C
C*    Find error and STOP if any
C
      IF (imrc .LT. 0) THEN
          WRITE(*,*) 'Problem in writing in the SHM pool for field',
     $        kindex 
          CALL ABORT('STOP in SIPC_Write_Model')
      ENDIF
C
C*    4. End of routine
C        --------------
C
      WRITE (*,*) ' '
      WRITE (*,*)' --------- End of routine SIPC_Write_model ---------'
C
      RETURN
      END
