CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/diawri.F,v 1.1.1.1.6.3 2002/02/04 13:45:12 maisonna Exp $
CDIR$ LIST       
      SUBROUTINE diawri ( kt, kindic )
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE diawri
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC     Standard output of opa: dynamics and tracer fields 
CCC     NETCDF format is used by default 
CCC
CCC     If "key_mpp" or "key_fdir, direct access format
CCC     IF "key_vairmer, Vairmer format
CCC
#ifdef key_fdir
#include "diawri.fdir.h"
#  elif defined key_mpp
#include "diawri.fdir.h"
#  elif defined key_vairmer
#include "diawri.vairmer.h"
#  else
CC
CC
CC   METHOD :
CC   -------
CC	At the beginning of the first time step (nit000), define all
CC	the NETCDF files and fields
CC
CC      At each time step call histdef to compute the mean if ncessary
CC	Each nwrite time step, output the instantaneous or mean fields
CC
CC	IF kindic <0, output of fields before the model interruption.
CC      IF kindic =0, time step loop
CC      IF kindic >0, output of fields before the time step loop
CC
CC
CC   INPUT :
CC   -----
CC      argument
CC              kt              : time step
CC		kindic		: indicator of abnormal termination
CC      common
CC            /COMCOH/          : orthogonal curvilinear coordinates
CC                                and scale factors
CC            /COMASK/          : masks, bathymetry
CC            /COMNOW/          : present fields (now)
CC            /CIMCDF/		: NETCDF variables
CC
CC   OUTPUT :
CC   ------
CC      file
CC              "clhstnam" files: at least one file for each grid
CC
CC
CC   WORKSPACE :
CC   ---------
CC      local
CC              
CC             
CC
CC   EXTERNAL :
CC   --------
CC	prihre, hist..., dianam
CC
CC   REFERENCES :                 no
CC   ----------
CC
CC   MODIFICATIONS:
CC   --------------
CC      original  : 91-03 ()
CC      additions : 91-11 (G. Madec)
CC      additions : 92-06 (M. Imbard) correction restart file
CC      additions : 92-07 (M. Imbard) split into diawri and rstwri
CC      additions : 93-03 (M. Imbard) suppress writibm
CC      additions : 94-12 (M. Imbard) vairmer format
CC      additions : 98-01 (C. Levy) NETCDF format using ioipsl INTERFACE
CC      additions : 99-02 (E. Guilyardi) name of netCDF files + variables
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
      USE ioipsl
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC Local declarations
CC ==================

      INTEGER kt,kindic
C
      INTEGER ji,jj
      LOGICAL clp
C
      CHARACTER*40 clhstnam
      CHARACTER*40 clop,clmax
      REAL zsto,zout,zmax
      REAL zwrite(jpi,jpj)
      INTEGER iyear,imonth,iday,iimi, iima, ijmi, ijma, ipk, it
      REAL zsec,zjulian,zdt
C
CC----------------------------------------------------------------------
CC Statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8.2, LODYC-IPSL (2001)
CCC---------------------------------------------------------------------
C
C
C 0. Initialisation
C -----------------
C
C local variable for debugging
      clp=.false.
      clp=clp.and.lwp
C
C Define frequency of output and means
      zdt = rdt
      IF ( nacc == 1 ) zdt = rdtmin
#if defined key_diainstant
      zsto=nwrite*zdt
      clop="inst(only(x))"
#else
      zsto=zdt
      clop="ave(only(x))"
#endif
      zout=nwrite*zdt
      zmax=(nitend-nit000+1)*zdt
C
C Define indexes of the horizontal output zoom
      iimi=1
      iima=jpi
      ijmi=1
      ijma=jpj
c ipk limit storage in depth
      ipk = jpk
c define time axis
      it= kt-nit000+1
C
C 1. Define NETCDF files and fields at beginning of first time step
C -----------------------------------------------------------------
C
      IF(clp)WRITE(numout,*)'diawri kt=',kt,' kindic ',kindic
      IF(kt.eq.nit000.and.kindic.eq.1) THEN
C
C... Define the NETCDF files (one per grid)
c
c   choose calendar for ioipsl
c
          IF (nbisex .eq. 1) THEN 
              CALL ioconf_calendar('gregorian')
          ELSE IF  (nbisex .eq. 0) THEN 
              CALL ioconf_calendar('noleap')
          ELSE IF (nbisex .eq. 30) THEN 
              CALL ioconf_calendar('360d')
          ENDIF 
C
C Compute julian date from starting date of the run
          iyear = ndastp/10000
          imonth = ndastp/100 - iyear*100
          iday = ndastp - imonth*100 - iyear*10000
          iyear = ndastp/10000
          zsec=0.
          CALL ymds2ju(iyear,imonth,iday,zsec,zjulian)
          IF(lwp)WRITE(numout,*)' '  
          IF(lwp)WRITE(numout,*)' Date 0 used :',nit000
     $        ,' YEAR ',iyear,' MONTH ',imonth,' DAY ',iday
     $        ,'Julian day : ',zjulian
C
c WRITE root name in date.file for use by postpro
c
          CALL dianam(clhstnam,nwrite,' ')
          WRITE(numwda,*)clhstnam

C
C... Define the T grid FILE (nid1)
C
          CALL dianam(clhstnam,nwrite,'grid_T')
          IF(lwp)WRITE(numout,*)" Name of NETCDF file ",
     $        clhstnam
C Horizontal grid : glamt and gphit
          IF(lwp)WRITE(numout,*)" indexes of zoom = ", 
     $      iimi, iima, ijmi, ijma
          IF(lwp)WRITE(numout,*)" limit storage in depth = ", ipk
C
          CALL histbeg(clhstnam, jpi, glamt, jpj, gphit,
     $        iimi, iima-iimi+1, ijmi, ijma-ijmi+1, 
     $        0, zjulian, zdt, nhorid1, nid1)
C Vertical grid : gdept
          CALL histvert(nid1, "deptht", "Vertical T levels",
     $        "m", ipk, gdept, ndepid1)
C Index of ocean points
          CALL wheneq(jpi*jpj*ipk,tmask,1,1.,ndex10,ndim10)
          CALL wheneq(jpi*jpj,tmask,1,1.,ndex11,ndim11)
C
C... Define the U grid FILE (nid2)
C
          CALL dianam(clhstnam,nwrite,'grid_U')
          IF(lwp)WRITE(numout,*)" Name of NETCDF file ",
     $        clhstnam
C Horizontal grid : glamu and gphiu
          CALL histbeg(clhstnam, jpi, glamu, jpj, gphiu,
     $        iimi, iima-iimi+1, ijmi, ijma-ijmi+1,
     $        0, zjulian, zdt, nhorid2, nid2)
C Vertical grid : gdept
          CALL histvert(nid2, "depthu", "Vertical U levels",
     $        "m", ipk, gdept, ndepid2)
C Index of ocean points
          CALL wheneq(jpi*jpj*ipk,umask,1,1.,ndex20,ndim20)
          CALL wheneq(jpi*jpj,umask,1,1.,ndex21,ndim21)
C
C... Define the V grid FILE (nid3)
C
          CALL dianam(clhstnam,nwrite,'grid_V')
          IF(lwp)WRITE(numout,*)" Name of NETCDF file ",
     $        clhstnam
C Horizontal grid : glamv and gphiv
          CALL histbeg(clhstnam, jpi, glamv, jpj, gphiv,
     $        iimi, iima-iimi+1, ijmi, ijma-ijmi+1,
     $        0, zjulian, zdt, nhorid3, nid3)
C Vertical grid : gdept
          CALL histvert(nid3, "depthv", "Vertical V levels",
     $        "m", ipk, gdept, ndepid3)
C Index of ocean points
          CALL wheneq(jpi*jpj*ipk,vmask,1,1.,ndex30,ndim30)
          CALL wheneq(jpi*jpj,vmask,1,1.,ndex31,ndim31)
C
C... Define the W grid FILE (nid4)
C
          CALL dianam(clhstnam,nwrite,'grid_W')
          IF(lwp)WRITE(numout,*)" Name of NETCDF file ",
     $        clhstnam
          CALL histbeg(clhstnam, jpi, glamt, jpj, gphit,
     $        iimi, iima-iimi+1, ijmi, ijma-ijmi+1, 
     $        0, zjulian, zdt, nhorid4, nid4)
          CALL histvert(nid4, "depthw", "Vertical W levels",
     $        "m", ipk, gdepw, ndepid4)
C
          ndex40 = ndex10
          ndim40 = ndim10
          ndex41 = ndex11
          ndim41 = ndim11
C
#if defined key_diatrdtra
C... Define the T_trend grid FILE (nid5)
C
          CALL dianam(clhstnam,nwrite,'T_tren')
          IF(lwp)WRITE(numout,*)" Name of NETCDF file ",
     $        clhstnam
C Horizontal grid : glamt and gphit
          CALL histbeg(clhstnam, jpi, glamt, jpj, gphit,
     $        iimi, iima-iimi+1, ijmi, ijma-ijmi+1, 
     $        0, zjulian, zdt, nhorid5, nid5)
C Vertical grid : gdept
          CALL histvert(nid5, "deptht", "Vertical T levels",
     $        "m", ipk, gdept, ndepid5)
C Index of ocean points
          CALL wheneq(jpi*jpj*ipk,tmask,1,1.,ndex50,ndim50)
          CALL wheneq(jpi*jpj,tmask,1,1.,ndex51,ndim51)
C
C... Define the S_trend grid FILE (nid6)
C
          CALL dianam(clhstnam,nwrite,'S_tren')
          IF(lwp)WRITE(numout,*)" Name of NETCDF file ",
     $        clhstnam
C Horizontal grid : glamt and gphit
          CALL histbeg(clhstnam, jpi, glamt, jpj, gphit,
     $        iimi, iima-iimi+1, ijmi, ijma-ijmi+1, 
     $        0, zjulian, zdt, nhorid6, nid6)
C Vertical grid : gdept
          CALL histvert(nid6, "deptht", "Vertical T levels",
     $        "m", ipk, gdept, ndepid6)
C Index of ocean points
          CALL wheneq(jpi*jpj*ipk,tmask,1,1.,ndex60,ndim60)
          CALL wheneq(jpi*jpj,tmask,1,1.,ndex61,ndim61)
#endif
c
C
C Declare all the output fields as NETCDF variables
C
C...nid1
C   ...3D
C      ...salinity
          CALL histdef(nid1, "vosaline", "Salinity", "PSU", jpi,
     $        jpj, nhorid1, ipk, 1, ipk, ndepid1, 32, clop, zsto,zout)
C      ...temperature 
          CALL histdef(nid1, "votemper", "Temperature", "C", jpi, jpj,
     $        nhorid1, ipk, 1, ipk, ndepid1, 32, clop, zsto, zout)
C   ...2D
C      ...sst
          CALL histdef(nid1, "sosstsst", "SST", "C",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop, zsto,zout)
C      ...sss
          CALL histdef(nid1, "sosaline", "SSS", "PSU",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop, zsto,zout)
#ifdef key_freesurf_cstvol
C      ...sea surface height eta
          CALL histdef(nid1, "sossheig", 
     $        "Sea Surface Height", "M",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#  else
C      ...barotropic stream function
          CALL histdef(nid1, "sobarstf", 
     $        "Barotropic Stream Function", "m3/s2",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
#endif
#if defined key_freesurf_cstvol && defined key_ice_lln
C sowaflup = sowaflep + sorunoff + sowafldp + a term associated to
C    internal damping to Levitus that can be diagnosed from others
C sowaflcd = sowaflep + sorunoff + sowafldp + iowaflup
C      ...ice to ocean freshwater budget (sbcocn(:,:,4))
          CALL histdef(nid1, "iowaflup", 
     $        "Ice to ocean freshwater budget", "kg/m2/s",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
C      ...atmosphere to ocean freshwater budget (sbcocn(:,:,10))
          CALL histdef(nid1, "sowaflep", 
     $        "atmosphere to ocean freshwater budget", "kg/m2/s",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
C      ...freshwater budget due to concentration/dilution effect (emps)
          CALL histdef(nid1, "sowaflcd", 
     $        "EMPS", "kg/m2/s",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#endif
C      ...total water flux
          CALL histdef(nid1, "sowaflup",
     $        "Net Upward Water Flux", "Kg/m2/S",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
C      ...run off
          CALL histdef(nid1, "sorunoff",
     $        "Run-off", "Kg/m2/S",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#if defined  key_ice_lln && defined key_coupled
C      ...calving
          CALL histdef(nid1, "socalvin",
     $        "Calving", "Kg/m2/S",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#endif
C      ...total water by salinity flux
          CALL histdef(nid1, "sosalflx",
     $        "E.S Flux", "KG/M2/S",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
C      ...total heat flux
          CALL histdef(nid1, "sohefldo",
     $        "Net Downward Heat Flux", "W/m2",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...solar heat flux
          CALL histdef(nid1, "soshfldo",
     $        "Shortwave Radiation", "W/m2",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...mixed layer depth
          CALL histdef(nid1, "somxl010",
     $        "Mixed Layer Depth 0.01", "m",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...turbocline depth
          CALL histdef(nid1, "somixhgt",
     $        "Turbocline Depth", "m",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...ice cover
          CALL histdef(nid1, "soicecov",
     $        "Ice Cover", "[0,1]",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#if ( ! defined key_coupled && defined key_flx )
C      ...heat flux damping
          CALL histdef(nid1, "sohefldp",
     $        "Heat Flux Damping", "W/m2",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...water flux damping
          CALL histdef(nid1, "sowafldp",
     $        "Water Flux Damping", "Kg/m2/s",
     &        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...water damping by salinity flux
          CALL histdef(nid1, "sosafldp",
     $        "ERP.S Flux", "KG/M2/s",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#endif
C
#if ( defined key_coupled && ! defined key_ice_igloo ) 
C damping arrays kept in coupled when using IF ice
C      ...heat flux damping
          CALL histdef(nid1, "sohefldp",
     $        "Heat Flux Damping", "W/m2",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...water flux damping
          CALL histdef(nid1, "sowafldp",
     $        "Water Flux Damping", "Kg/m2/s",
     &        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...water damping by salinity flux
          CALL histdef(nid1, "sosafldp",
     $        "ERP.S Flux", "Kg/m2/s",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
#endif
#if defined key_diaspr
C      ... surface pressure
          CALL histdef(nid1, "sosurfps",
     $        "Surface Pressure", "CM",
     $        jpi, jpj, nhorid1, 1, 1, 1, -99, 32, clop,zsto,zout)
#endif
C      ... bowl INDEX (= imax of nmln on period)
          clmax ="l_max(only(x))"
          CALL histdef(nid1, "sobowlin",
     $        "Bowl Index", "W point",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clmax,zsto,zmax)
#if defined key_diahth
C      ... thermocline depth
          CALL histdef(nid1, "sothedep",
     $        "Thermocline Depth", "m",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ... depth of 20C
          CALL histdef(nid1, "so20chgt",
     $        "Depth of 20C isotherm", "m",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ... depth of 28C
          CALL histdef(nid1, "so28chgt",
     $        "Depth of 28C isotherm", "m",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ... heat content of first 300 m
          CALL histdef(nid1, "sohtc300",
     $        "Heat content 300 m", "W",
     $        jpi, jpj, nhorid1, 1, 1, 1, - 99, 32, clop,zsto,zout)
#endif
C
          CALL histend(nid1)
C...nid2
C   ...3D
C      ...zonal current
          CALL histdef(nid2, "vozocrtx", "Zonal Current", "m/s", jpi
     $        , jpj, nhorid2, ipk, 1, ipk, ndepid2, 32, clop, zsto,zout)
C
#if defined key_trahdfeiv && defined key_diaeiv
C      ...zonal eiv current
          CALL histdef(nid2, "vozoeivu", "Zonal EIV Current", "m/s", jpi
     $        , jpj, nhorid2, ipk, 1, ipk, ndepid2, 32, clop, zsto,zout)
#endif
C
#if defined key_diatrddyn
          CALL histdef(nid2, "votuhpgr", "Pressure Gradient Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
#if defined key_trddyn_new
          CALL histdef(nid2, "votuadzo", "Zonal Advection",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2, "votuadme", "Meridional Advection",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
#else
          CALL histdef(nid2, "votunoli", "KE Gradient Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2, "votuvort", "Relative Vorticity Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
#endif
          CALL histdef(nid2, "votucori", "Coriolis Term Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2, "votuhodi", "Horizontal Diffusion Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2, "votuvead", "Vertical Advection Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2, "votuvedi", "Vertical Diffusion Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2,"votuspgr","Surface Pressure Gradient Trend"
     $        ,"m/s2",jpi,jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
          CALL histdef(nid2, "Votudamp", "Dampimg Term Trend",
     $        "m/s2",jpi, jpj,nhorid2, ipk, 1, ipk, ndepid2, 32, clop,
     $        zsto,zout)
#endif
C   ...2D
C      ...zonal presure gradient
          CALL histdef(nid2, "sozospgx", 
     $        "Zonal Surface Pressure Gradient", "N/kg",
     $        jpi, jpj, nhorid2, 1, 1, 1, -99, 32, clop,zsto,zout)
C      ...zonal stress
          CALL histdef(nid2, "sozotaux",
     $        "Wind Stress along i", "N/m2",
     $        jpi, jpj, nhorid2, 1, 1, 1, - 99, 32, clop,zsto,zout)
          CALL histend(nid2)
C...nid3
C   ...3D
C      ...meridonal current
          CALL histdef(nid3, "vomecrty", 
     $        "Meridional Current", "m/s", jpi, jpj, nhorid3, ipk, 1
     $        , ipk, ndepid3, 32, clop, zsto,zout) 
C
#if defined key_trahdfeiv && defined key_diaeiv
C      ...meridional eiv current
          CALL histdef(nid3, "vomeeivv",
     $        "Meridional EIV Current", "m/s",jpi, jpj, nhorid3, ipk, 1,
     $        ipk, ndepid3, 32, clop, zsto,zout)
#endif
C
#if defined key_diatrddyn
          CALL histdef(nid3, "votvhpgr", "Pressure Gradient Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
#if defined key_trddyn_new
          CALL histdef(nid3, "votvadzo", "Zonal Advection",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3, "votvadme", "Meridional Advection",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
#else
          CALL histdef(nid3, "votvnoli", "KE Gradient Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3, "votvvort", "Relative Vorticity Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
#endif
          CALL histdef(nid3, "votvcori", "Coriolis Term Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3, "votvhodi", "Horizontal Diffusion Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3, "votvvead", "Vertical Advection Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3, "votvvedi", "Vertical Diffusion Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3,"votvspgr","Surface Pressure Gradient Trend"
     $        ,"m/s2",jpi,jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
          CALL histdef(nid3, "Votvdamp", "Dampimg Term Trend",
     $        "m/s2",jpi, jpj,nhorid3, ipk, 1, ipk, ndepid3, 32, clop,
     $        zsto,zout)
#endif
C   ...2D
C      ...meridonal presure gradient
          CALL histdef(nid3, "somespgy",
     $        "Meridional Surface Pressure Gradient", "N/kg",
     $        jpi, jpj, nhorid3, 1, 1, 1, - 99, 32, clop,zsto,zout)
C      ...meridonal stress
          CALL histdef(nid3, "sometauy",
     $         "Wind Stress along j", "N/m2",
     &         jpi, jpj, nhorid3, 1, 1, 1, - 99, 32, clop,zsto,zout)
          CALL histend(nid3)
C...nid4
C   ...3D
C      ...vertical current
          CALL histdef(nid4, "vovecrtz", 
     $        "Vertical Velocity", "m/s",jpi, jpj, nhorid4, ipk, 1,
     $        ipk, ndepid4, 32, clop, zsto,zout) 
C      ...vertical eddy diffusivity for tracers
          CALL histdef(nid4, "votkeavt", "Vertical Eddy Diffusivity",
     $        "m2/s", jpi, jpj, nhorid4, ipk, 1, ipk, ndepid4, 32, clop,
     $        zsto,zout)
#if defined key_ddmixing
          CALL histdef(nid4,"voddmavs","Salt Vertical Eddy Diffusivity",
     $        "m2/s", jpi, jpj, nhorid4, ipk, 1, ipk, ndepid4, 32, clop,
     $        zsto,zout)
          CALL histdef(nid4,"voddmrra","Heat/Salt buoyancy Ratio",
     $        "-", jpi, jpj, nhorid4, ipk, 1, ipk, ndepid4, 32, clop,
     $        zsto,zout)
#endif
C   ...2D
#if defined key_trahdfeiv
#    if defined key_trahdfcoef2d
C      ...lateral eddy diffusivity for tracers
          CALL histdef(nid4, "soleahtw",
     $        "lateral eddy diffusivity", "m2/s", jpi, jpj, nhorid4,
     $        1, 1, 1,  - 99, 32, clop, zsto,zout)
C      ...EIV coefficient at w-point 
          CALL histdef(nid4, "soleaeiw",
     $ "eddy induced vel. coefficient at w-point", "m2/s",
     $     jpi, jpj, nhorid4,
     $        1, 1, 1,  - 99, 32, clop, zsto,zout)
#    endif
#    if defined key_diaeiv
C      ...vertical eiv current
          CALL histdef(nid4, "voveeivw",
     $        "Vertical EIV Velocity", "m/s",jpi, jpj, nhorid4, ipk, 1,
     $        ipk, ndepid4, 32, clop, zsto,zout)
#    endif
#endif
          CALL histend(nid4)
#if defined key_diatrdtra
C...nid5
C   ...3D
          CALL histdef(nid5, "vottzoad", "Zonal Advection Trend",
     $        "C/s",jpi, jpj,nhorid5, ipk, 1, ipk, ndepid5, 32, clop,
     $        zsto,zout)
          CALL histdef(nid5, "vottmead", "Meridional Advection Trend",
     $        "C/s",jpi, jpj,nhorid5, ipk, 1, ipk, ndepid5, 32, clop,
     $        zsto,zout)
          CALL histdef(nid5, "vottvead", "Vertical Advection Trend",
     $        "C/s",jpi, jpj,nhorid5, ipk, 1, ipk, ndepid5, 32, clop,
     $        zsto,zout)
          CALL histdef(nid5, "votthodi", "Horizontal Diffusion Trend",
     $        "C/s",jpi, jpj,nhorid5, ipk, 1, ipk, ndepid5, 32, clop,
     $        zsto,zout)
          CALL histdef(nid5, "vottvedi", "Vertical Diffusion Trend",
     $        "C/s",jpi, jpj,nhorid5, ipk, 1, ipk, ndepid5, 32, clop,
     $        zsto,zout)
          CALL histend(nid5)
C...nid6
C   ...3D
          CALL histdef(nid6, "votszoad", "Zonal Advection Trend",
     $        "PSU/s",jpi, jpj,nhorid6, ipk, 1, ipk, ndepid6, 32, clop,
     $        zsto,zout)
          CALL histdef(nid6, "votsmead", "Meridional Advection Trend",
     $        "PSU/s",jpi, jpj,nhorid6, ipk, 1, ipk, ndepid6, 32, clop,
     $        zsto,zout)
          CALL histdef(nid6, "votsvead", "Vertical Advection Trend",
     $        "PSU/s",jpi, jpj,nhorid6, ipk, 1, ipk, ndepid6, 32, clop,
     $        zsto,zout)
          CALL histdef(nid6, "votshodi", "Horizontal Diffusion Trend",
     $        "PSU/s",jpi, jpj,nhorid6, ipk, 1, ipk, ndepid6, 32, clop,
     $        zsto,zout)
          CALL histdef(nid6, "votsvedi", "Vertical Diffusion Trend",
     $        "PSU/s",jpi, jpj,nhorid6, ipk, 1, ipk, ndepid6, 32, clop,
     $        zsto,zout)
          CALL histend(nid6)
#endif
          ndex(1) = 0
          IF(lwp)WRITE(numout,*)' '  
          IF(lwp)WRITE(numout,*)' End of NETCDF Initialization'
          IF(lwp)WRITE(numout,*)' '  
      ELSE
C
C
C 2. Start writing data
C ---------------------
C
C ndex(1) est utilise ssi l'avant dernier argument est diffferent de 
C la taille du tableau en sortie. Dans ce cas , l'avant dernier argument
C donne le nombre d'elements, et ndex la liste des indices a sortir
C
          IF(lwp .and. mod( kt, nwrite ).EQ.0)
     $        WRITE(numout,*) '**** diawri : write NetCDF fields'
C Write fields on T grid
          CALL histwrite(nid1, "vosaline", it, sn,      ndim10,ndex10)
          IF(clp) WRITE(numout,*)' diawri histwrite sn'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "votemper", it, tn,      ndim10,ndex10)
          IF(clp) WRITE(numout,*)' diawri histwrite tn'
          IF(clp) CALL FLUSH(numout)
#if defined key_diatrdtra
          CALL histwrite(nid5, "vottzoad", it, ttrdh(:,:,:,1),ndim50,
     $        ndex50)
          IF(clp) WRITE(numout,*)' diawri histwrite tzoad'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid5, "vottmead", it, ttrdh(:,:,:,2),ndim50,
     $        ndex50)
          CALL histwrite(nid5, "vottvead", it, ttrd(:,:,:,2),ndim50,
     $        ndex50)
          CALL histwrite(nid5, "votthodi", it, ttrd(:,:,:,3),ndim50,
     $        ndex50)
          CALL histwrite(nid5, "vottvedi", it, ttrd(:,:,:,4),ndim50,
     $        ndex50)
          CALL histwrite(nid6, "votszoad", it, strdh(:,:,:,1),ndim60,
     $        ndex60)
          IF(clp) WRITE(numout,*)' diawri histwrite szoad'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid6, "votsmead", it, strdh(:,:,:,2),ndim60,
     $        ndex60)
          CALL histwrite(nid6, "votsvead", it, strd(:,:,:,2),ndim60,
     $        ndex60)
          CALL histwrite(nid6, "votshodi", it, strd(:,:,:,3),ndim60,
     $        ndex60)
          CALL histwrite(nid6, "votsvedi", it, strd(:,:,:,4),ndim60,
     $        ndex60)
#endif
          CALL histwrite(nid1, "sosstsst", it,  tn(:,:,1),ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite sst'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sosaline", it,  sn(:,:,1),ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite sss'
          IF(clp) CALL FLUSH(numout)
#ifdef key_freesurf_cstvol
          CALL histwrite(nid1, "sossheig", it, etan,   ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite eta'
          IF(clp) CALL FLUSH(numout)
#  else
          CALL histwrite(nid1, "sobarstf", it, bsfn,   ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite bsf'
          IF(clp) CALL FLUSH(numout)
#endif
#if defined key_freesurf_cstvol && defined key_ice_lln
          CALL histwrite(nid1,"iowaflup", it,
     $                                     sbcocn(:,:,4),ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite iowaflup'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sowaflep", it,
     $                                     sbcocn(:,:,10),ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite sowaflep'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sowaflcd", it, emps,ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite sowaflcd'
          IF(clp) CALL FLUSH(numout)
#endif
          CALL histwrite(nid1, "sowaflup", it,  emp,    ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite sowaflup'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sorunoff", it,  runoff, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite sorunoff'
          IF(clp) CALL FLUSH(numout)
#if defined key_ice_lln  && defined key_coupled
          CALL histwrite(nid1, "socalvin", it,  calv,  ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite socalvin'
          IF(clp) CALL FLUSH(numout)
#endif
          DO jj = 1,jpj
            DO ji = 1,jpi
              zwrite(ji,jj) = emp(ji,jj)*sn(ji,jj,1)*tmask(ji,jj,1)
            END DO
          END DO
          CALL histwrite(nid1, "sosalflx", it, zwrite , ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite emp*sn'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sohefldo",   it, qt,      ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite qt'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "soshfldo", it, qsr,    ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite qsr'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "somxl010", it, hmlp,  ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite hmlp'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "somixhgt", it, hmld,  ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite hmld'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "soicecov", it, freeze, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite freeze'
          IF(clp) CALL FLUSH(numout)
#if ( ! defined key_coupled && defined  key_flx )
          CALL histwrite(nid1, "sohefldp", it, qrp, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite qrp'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sowafldp", it, erp, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite erp'
          IF(clp) CALL FLUSH(numout)
          DO jj=1,jpj
            DO ji=1,jpi
              zwrite(ji,jj) = erp(ji,jj)*sn(ji,jj,1)*tmask(ji,jj,1)
            END DO
          END DO
          CALL histwrite(nid1, "sosafldp", it, zwrite, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite erp*sn'
          IF(clp) CALL FLUSH(numout)
#endif
#if ( defined key_coupled && ! defined key_ice_igloo ) 
          CALL histwrite(nid1, "sohefldp", it, qrp, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite qrp'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sowafldp", it, erp, ndim11,ndex11)
          DO jj = 1,jpj
            DO ji = 1,jpi
              zwrite(ji,jj) = erp(ji,jj)*sn(ji,jj,1)*tmask(ji,jj,1)
            END DO
          END DO
          CALL histwrite(nid1, "sosafldp", it, zwrite, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite erp_sn'
          IF(clp) CALL FLUSH(numout)
#endif
#if defined key_diaspr
          CALL histwrite(nid1, "sosurfps", it, gps, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite gps'
          IF(clp) CALL FLUSH(numout)
#endif
          DO jj = 1,jpj
            DO ji = 1,jpi
              zwrite(ji,jj) = FLOAT(nmln(ji,jj))*tmask(ji,jj,1)
            END DO
          END DO
          CALL histwrite(nid1, "sobowlin", it, zwrite, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite nmln'
          IF(clp) CALL FLUSH(numout)
#if defined key_diahth
          CALL histwrite(nid1, "sothedep", it, hth, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite hth'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "so20chgt", it, hd20, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite hd20'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "so28chgt", it, hd28, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite hd28'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid1, "sohtc300", it, htc3, ndim11,ndex11)
          IF(clp) WRITE(numout,*)' diawri histwrite htc3'
          IF(clp) CALL FLUSH(numout)
#endif
C Write fields on U grid
          CALL histwrite(nid2, "vozocrtx", it, un, ndim20,ndex20)
          IF(clp) WRITE(numout,*)' diawri histwrite un'
          IF(clp) CALL FLUSH(numout)
#if defined key_trahdfeiv && defined key_diaeiv
C      ...zonal eiv current
          CALL histwrite(nid2, "vozoeivu", it, ugm, ndim20,ndex20)
#endif
#if defined key_diatrddyn
          CALL histwrite(nid2, "votuhpgr", it, utrd(:,:,:,1),
     $        ndim20,ndex20)
#    if defined key_trddyn_new
          CALL histwrite(nid2, "votuadzo", it, utrd(:,:,:,3),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "votuadme", it, utrd(:,:,:,2),
     $        ndim20,ndex20)
#    else
          CALL histwrite(nid2, "votunoli", it, utrd(:,:,:,2),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "votuvort", it, utrd(:,:,:,3),
     $        ndim20,ndex20)
#    endif
          CALL histwrite(nid2, "votucori", it, utrd(:,:,:,4),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "votuhodi", it, utrd(:,:,:,5),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "votuvead", it, utrd(:,:,:,6),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "votuvedi", it, utrd(:,:,:,7),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "votuspgr", it, utrd(:,:,:,8),
     $        ndim20,ndex20)
          CALL histwrite(nid2, "Votudamp", it, utrd(:,:,:,9),
     $        ndim20,ndex20)
#endif
          CALL lbc2( spgu, 2, 0, 1, 1, 1, 1 )
          CALL histwrite(nid2, "sozospgx", it, spgu, ndim21,ndex21)
          IF(clp) WRITE(numout,*)' diawri histwrite spgu'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid2, "sozotaux", it, taux, ndim21,ndex21)
          IF(clp) WRITE(numout,*)' diawri histwrite taux'
          IF(clp) CALL FLUSH(numout)

C Write fields on V grid
          CALL histwrite(nid3, "vomecrty", it, vn, ndim30,ndex30)
          IF(clp) WRITE(numout,*)' diawri histwrite vn'
          IF(clp) CALL FLUSH(numout)
#if defined key_trahdfeiv && defined key_diaeiv
C      ...meridional eiv current
          CALL histwrite(nid3, "vomeeivv", it, vgm, ndim30,ndex30)
#endif
#if defined key_diatrddyn
          CALL histwrite(nid3, "votvhpgr", it, vtrd(:,:,:,1),
     $        ndim20,ndex20)
#    if defined key_trddyn_new
          CALL histwrite(nid3, "votvadzo", it, vtrd(:,:,:,2),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "votvadme", it, vtrd(:,:,:,3),
     $        ndim20,ndex20)
#    else
          CALL histwrite(nid3, "votvnoli", it, vtrd(:,:,:,2),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "votvvort", it, vtrd(:,:,:,3),
     $        ndim20,ndex20)
#    endif
          CALL histwrite(nid3, "votvcori", it, vtrd(:,:,:,4),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "votvhodi", it, vtrd(:,:,:,5),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "votvvead", it, vtrd(:,:,:,6),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "votvvedi", it, vtrd(:,:,:,7),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "votvspgr", it, vtrd(:,:,:,8),
     $        ndim20,ndex20)
          CALL histwrite(nid3, "Votvdamp", it, vtrd(:,:,:,9),
     $        ndim20,ndex20)
#endif
          CALL lbc2( spgv, 3, 0, 1, 1, 1, 1 )
          CALL histwrite(nid3, "somespgy", it, spgv, ndim31,ndex31)
          IF(clp) WRITE(numout,*)' diawri histwrite spgv'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid3, "sometauy", it, tauy, ndim31,ndex31)
          IF(clp) WRITE(numout,*)' diawri histwrite tauy'
          IF(clp) CALL FLUSH(numout)
C Write fields on W grid
          CALL histwrite(nid4, "vovecrtz", it, wn, ndim40,ndex40)
          IF(clp) WRITE(numout,*)' diawri histwrite wn'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid4, "votkeavt", it, avt, ndim40,ndex40)
          IF(clp) WRITE(numout,*)' diawri histwrite avt'
          IF(clp) CALL FLUSH(numout)
#if defined key_ddmixing
          CALL histwrite(nid4, "voddmavs", it, avs, ndim40,ndex40)
          IF(clp) WRITE(numout,*)' diawri histwrite avt'
          IF(clp) CALL FLUSH(numout)
          CALL histwrite(nid4, "voddmrra", it, rrau, ndim40,ndex40)
          IF(clp) WRITE(numout,*)' diawri histwrite avt'
          IF(clp) CALL FLUSH(numout)
#endif
#if defined key_trahdfeiv
#    if defined key_trahdfcoef2d
C      ...lateral eddy diffusivity for tracers
          CALL histwrite(nid4, "soleahtw", it, ahtw, ndim41,ndex41)
C      ...EIV coefficient at w-point 
          CALL histwrite(nid4, "soleaeiw", it, aeiw, ndim41,ndex41)
#    endif
#    if defined key_diaeiv
C      ...vertical eiv current
          CALL histwrite(nid4, "voveeivw", it, wgm, ndim40,ndex40)
#    endif
#endif
      ENDIF
C
C 3. Synchronise and close all files
C ---------------------------------------
      IF( mod(kt,nwrite) == 0 .OR. kindic < 0 ) THEN
          CALL histsync(nid1)
          CALL histsync(nid2)
          CALL histsync(nid3)
          CALL histsync(nid4)
#if defined key_diatrdtra
          CALL histsync(nid5)
          CALL histsync(nid6)
#endif
      ENDIF
C
C ... Force output files if S < 0 or u > 20 m/s
      IF( kindic < 0 ) THEN
          CALL diabort
      ENDIF
C
      IF ( kt == nitend .OR. kindic < 0 ) THEN
          CALL histclo(nid1)
          CALL histclo(nid2)
          CALL histclo(nid3)
          CALL histclo(nid4)
#if defined key_diatrdtra
          CALL histclo(nid5)
          CALL histclo(nid6)
#endif
      ENDIF
#    endif
C
C
      RETURN
      END
