CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/dtacof.F,v 1.1.1.1.6.2 2002/02/04 13:45:14 maisonna Exp $
CDIR$ LIST
      SUBROUTINE dtacof
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE dtacof
CCC                     ******************
CCC
CCC                   **** W A R N I N G ****
CCC
CCC                     GLOBAL OCEAN VERSION
CCC			       ORCA
CCC
CCC  Purpose :
CCC  --------
CCC     Compute the arrays used for newtonian damping on tracer fields
CCC     ( if "key_tradmp" key activated )
CCC
CC   Method :
CC   -------
CC      Arrays defining the damping are computed for each grid
CC      point for temperature and salinity (resto)
CC      Damping depends on distance to coast, depth and latitude
CC
CC   Input :
CC   ------
CC      argument                : no
CC      common
CC            /COMTDP/          : temperature and salinity damping
CC
CC   Output :
CC   -------
CC      argument                : no
CC      common
CC            /COMTDP/          : temperature and salinity damping
CC               resto          : array of restoring coeff. on T and S
CC
CC   External :
CC   ---------                  IOIPSL  
CC
CC   Modifications :
CC   --------------
CC      original  : 91-03 ()
CC      additions : 91-11 (C. Levy)
CC                : 92-06 doctor norme (M. Imbard)
CC                : 96-01 (G. Madec) statement function for e3
CC                : 98-07 (M. Imbard, G. Madec) ORCA version
CC                : 00-08 (G. Madec, D. Ludicone) 
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CDIR$ NOLIST
      USE ioipsl
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
#if defined key_tradmp
CC local declarations
CC ==================
      INTEGER ji, jj, jk, je
      INTEGER jpmois
      PARAMETER (jpmois=1)
      INTEGER ipi, ipj, ipk
      INTEGER itime, iyear, imonth, iday, istep(jpmois), ie
      LOGICAL clbon
      CHARACTER*32 clname, clname2, clname3
      REAL zdate0, zsec
      REAL zinfl, zlon, zlat, zlat0, zlat1, zlat2
      REAL zsdmp, zbdmp, zhfac(jpk)
      REAL zdct(jpi,jpj,jpk), zmrs(jpi,jpj)
      REAL zlamt(jpi,jpj),zphit(jpi,jpj), zdept(jpk)
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8.2, LODYC-IPSL (2001)
CCC---------------------------------------------------------------------
C
#if defined key_arctic || defined key_antarctic
C ====================================================
C  ORCA configuration : arctic zoom or antarctic zoom
C ====================================================
C
      IF(lwp)WRITE(numout,*)
#if defined key_arctic
      IF(lwp)WRITE(numout,*) ' dtacof : Arctic zoom of ORCA'
#elif defined key_antarctic
      IF(lwp)WRITE(numout,*) ' dtacof : Antarctic zoom of ORCA'
#endif
      IF(lwp)WRITE(numout,*) ' -------------------------------'
      IF(lwp)WRITE(numout,*) 
C
C ... Initialization : 
C     zlat0 : latitude strip where resto decreases
C     zlat1 : resto = 1 before zlat1
C     zlat2 : resto decreases from 1 to 0 between zlat1 and zlat2
      resto(:,:,:) = 0.e0
      zlat0 = 10.
      zlat1 = 30.
      zlat2 = zlat1 + zlat0
C
C ... Compute arrays resto ; value for internal damping : 5 days
      DO jk = 2, jpkm1
        DO jj = 1, jpj
          DO ji = 1, jpi
            zlat = ABS( gphit(ji,jj) )
            IF ( zlat1 <= zlat .AND. zlat <= zlat2 ) THEN
                resto(ji,jj,jk) = 0.5 * ( 1./(5.*rday) ) *
     $                           ( 1. - cos(rpi*(zlat2-zlat)/zlat0) ) 
              ELSE IF ( zlat < zlat1 ) THEN
                resto(ji,jj,jk) = 1./(5.*rday)
            ENDIF
          END DO
        END DO
      END DO
C
C ... Mask resto array
          resto(:,:,:) = resto(:,:,:) * tmask(:,:,:)
C
#else
C ====================================
C  ORCA configuration : global domain
C ====================================
C
      IF(lwp)WRITE(numout,*)
      IF(lwp)WRITE(numout,*) ' dtacof : Global domain of ORCA'
      IF(lwp)WRITE(numout,*) ' ------------------------------'
      IF(lwp)WRITE(numout,*)
C
C ... Initialization : 
C   zdct()      : distant to the coastline
C   resto()     : array of restoring coeff. on T and S
C
      zdct (:,:,:) = 0.e0
      resto(:,:,:) = 0.e0
C
      IF ( ndmp > 0 ) THEN
C
C    ------------------------------------
C     Damping poleward of 'ndmp' degrees
C    ------------------------------------
C
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*)
     $                   ' ***** : Damping poleward of ', ndmp,' deg.'
          IF(lwp)WRITE(numout,*)
C
C ... Distance to coast (zdct)
C
C   ... Test the existance of distance-to-coast file
          itime = jpmois
          ipi = jpi
          ipj = jpj
          ipk = jpk
          clname = 'dist.coast'
          DO je=1,32
            IF( clname(je:je) == ' ' ) go to 140
          END DO
 140      CONTINUE
          ie=je
          clname2 = clname(1:ie-1)//".nc"
          inquire( FILE=clname2, EXIST=clbon )
C
          IF ( clbon ) THEN
C
C   ... Read file distance to coast if possible
              CALL flinopen( clname, nizoom, jpi, njzoom, jpj, .false.,
     $            ipi, ipj, ipk, zlamt, zphit, zdept, itime,
     $            istep, zdate0, rdt, numcot )
              CALL flinget( numcot, 'Tcoast', jpidta, jpjdta, jpk, 
     $           itime, 1, 1, nizoom, jpi, njzoom, jpj, zdct )
              CALL flinclo( numcot )
              IF(lwp)WRITE(numout,*) '    ** : File dist.coast.nc read'
C
          ELSE
C
C   ... Compute and save the distance-to-coast array (output in zdct)
              CALL cofdis ( zdct )
C
          ENDIF
C
C ... Compute arrays resto 
C      zinfl : distance of influence for damping term
C      zlat0 : latitude strip where resto decreases
C      zlat1 : resto = 0 between -zlat1 and zlat1
C      zlat2 : resto increases from 0 to 1 between |zlat1| and |zlat2|
C          and resto = 1 between |zlat2| and 90 deg.
          zinfl = 1000.e3
          zlat0 = 10
          zlat1 = ndmp
          zlat2 = zlat1 + zlat0
C
          DO jj = 1, jpj
            DO ji = 1, jpi
              zlat = ABS( gphit(ji,jj) )
              IF ( zlat1 <= zlat .AND. zlat <= zlat2 ) THEN
                  resto(ji,jj,1) = 0.5 *
     $                            ( 1. - cos(rpi*(zlat-zlat1)/zlat0 ) )
              ELSEIF ( zlat > zlat2 ) THEN
                  resto(ji,jj,1) = 1.
              ENDIF
            END DO
          END DO
C                   
C   ... North Indian ocean (20N/30N x 45E/100E) : resto=0
          IF ( ndmp == 20 ) THEN
              DO jj = 1, jpj
                DO ji = 1, jpi
                  zlat = gphit(ji,jj)
                  zlon = MOD( glamt(ji,jj), 360. )
                  IF ( zlat1 < zlat .AND. zlat < zlat2 .AND.
     $                  45.  < zlon .AND. zlon < 100. ) THEN
                      resto(ji,jj,1) = 0.
                  ENDIF
                END DO
              END DO
          ENDIF
C
          zsdmp = 1./(sdmp * rday)
          zbdmp = 1./(bdmp * rday)
          DO jk = 2, jpkm1
            DO jj = 1, jpj
              DO ji = 1, jpi
                zdct(ji,jj,jk) = min( zinfl, zdct(ji,jj,jk) )
C 
C   ... Decrease the value in the vicinity of the coast
                resto(ji,jj,jk) = resto(ji,jj,1)*0.5
     $                 * ( 1. - cos( rpi*zdct(ji,jj,jk)/zinfl) )
C
C   ... Vertical variation from zsdmp (sea surface) to zbdmp (bottom)
                resto(ji,jj,jk) = resto(ji,jj,jk)*
     $             ( zbdmp + (zsdmp-zbdmp)*exp(-fsdept(ji,jj,jk)/hdmp) )
              END DO
            END DO
          END DO
C
      ENDIF
C
C
      IF ( ndmp > 0 .OR. ndmp == -1 ) THEN
C
C    -------------------------
C     Med and Red Sea damping
C    -------------------------
C
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*) ' ***** : Damping in Med and Red Seas'
          IF(lwp)WRITE(numout,*)
C
C ... Initialization
C     zmrs(:,:)   : damping term on the Med or Red Sea
C
          zmrs(:,:) = 0.e0
C
C ... Compute arrays over Mediterranean Sea and Red Sea
C      C A U T I O N  we introduce area corner index for global grid
C
#if defined key_orca_r4
C   ... ORCA_R4 configuration :
C     ... Mediterranean Sea
          DO jj = kfindj0(50), kfindj1(56)
            DO ji = kfindi0(81), kfindi1(91)
              zmrs(ji,jj) = 1.
            END DO
          END DO
          DO jj = kfindj0(50), kfindj1(55)
            DO ji = kfindi0(75), kfindi1(80)
              zmrs(ji,jj) = 1.
            END DO
          END DO
          DO jj = kfindj0(52), kfindj1(53)
            DO ji = kfindi0(70), kfindi1(74)
              zmrs(ji,jj) = 1.
            END DO
          END DO
#endif
#if defined key_orca_r2
C   ... ORCA_R2 configuration :
C     ... Mediterranean Sea
          DO jj = kfindj0(96), kfindj1(110)
            DO ji = kfindi0(157), kfindi1(181)
              zmrs(ji,jj) = 1.
            END DO
          END DO
          DO jj = kfindj0(100), kfindj1(110)
            DO ji = kfindi0(144), kfindi1(156)
              zmrs(ji,jj) = 1.
            END DO
          END DO
          DO jj = kfindj0(100), kfindj1(103)
            DO ji = kfindi0(139), kfindi1(143)
              zmrs(ji,jj) = 1.
            END DO
          END DO
C     ... Decrease before Gibraltar Strait
          DO jj = kfindj0(101), kfindj1(102)
            DO ji = kfindi0(139), kfindi1(141)
              zmrs(ji,jj) = 0.
            END DO
            DO ji = kfindi0(142), kfindi1(142)
              zmrs(ji,jj) = 1./90.
            END DO
            DO ji = kfindi0(143), kfindi1(143)
              zmrs(ji,jj) = 0.4
            END DO
            DO ji = kfindi0(144), kfindi1(144)
              zmrs(ji,jj) = 0.75
            END DO
          END DO
C     ... Red Sea
          DO jj = kfindj0(87), kfindj1(96)
            DO ji = kfindi0(147), kfindi1(163)
              zmrs(ji,jj) = 1.
            END DO
          END DO
C     ... Decrease before Bab el Mandeb Strait
          DO jj = kfindj0(91), kfindj1(91)
            DO ji = kfindi0(153), kfindi1(160)
              zmrs(ji,jj) = 0.8
            END DO
          END DO
          DO jj = kfindj0(90), kfindj1(90)
            DO ji = kfindi0(153), kfindi1(160)
              zmrs(ji,jj) = 0.4
            END DO
          END DO
          DO jj = kfindj0(89), kfindj1(89)
            DO ji = kfindi0(158), kfindi1(160)
              zmrs(ji,jj) = 1./90.
            END DO
          END DO
          DO jj = kfindj0(88), kfindj1(88)
            DO ji = kfindi0(160), kfindi1(163)
              zmrs(ji,jj) = 0.
            END DO
          END DO
#endif
#if defined key_orca_r05 || defined key_orca_r025
C   ... ORCA_R05 and ORCA_R025 configuration :
          IF (lwp) THEN 
              WRITE(numout,*)' ***** : Not yet implemented in ORCA_R05'
              WRITE(numout,*)'                         and in ORCA_R025'
          ENDIF
          STOP 'dtacof'
#endif
C
C ... Smooth transition from 0 at surface to 1./rday at the 18th level
C     in Med and Red Sea
          DO jk = 1, 17
            zhfac (jk) = 0.5*( 1.-cos(rpi*(jk-1)/16.) )/rday
          END DO
          DO jk = 18, jpkm1
            zhfac (jk) = 1./rday
          END DO
          DO jk = 1, jpkm1
            resto(:,:,jk) =      zmrs(:,:)  *zhfac(jk)
     $                    + ( 1.-zmrs(:,:) )*resto(:,:,jk)
          END DO
C
C ... Mask resto array and set to 0 first and last levels
          resto(:,:, : ) = resto(:,:,:) * tmask(:,:,:)
          resto(:,:, 1 ) = 0.e0
          resto(:,:,jpk) = 0.e0
C
        ELSE
C 
C    ------------
C     No damping
C    ------------
C 
          IF(lwp)WRITE(numout,*) ' ***** : Choose a correct value ',
     $                           'of ndmp or DO NOT defined key_tradmp'
          STOP 'dtacof.F'
      ENDIF
C
#endif
C
C    ----------------------------
C     Create Print damping array
C    ----------------------------
C
C ndmpf   : = 1 create a damping.coeff NetCDF file
C
      IF ( ndmpf == 1 ) THEN
          IF(lwp)WRITE(numout,*) ' ***** : create damping.coeff.nc file'
          itime=0
          clname3='damping.coeff'
          iyear=0
          imonth=1
          iday=1
          zsec=0.
          CALL ymds2ju(iyear,imonth,iday,zsec,zdate0)
          CALL restini('NONE',jpi,jpj,glamt,gphit,jpk,gdept,clname3
     $        ,itime,zdate0,rdt,numdmp)
          CALL restput(numdmp,'Resto',jpi,jpj,jpk,0,resto)
          CALL restclo(numdmp)
      END IF
C
#endif
C
      RETURN
      END
