CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/dtasal.monthly.h,v 1.1.1.1.6.1 2002/02/04 13:45:15 maisonna Exp $
CCC
CCC        DTASAL.MONTHLY
CCC      *****************
CCC
CCC  PURPOSE :
CCC  ---------
CCC     Reads salinity data (Levitus monthly data)
CCC                          =======
CCC
CC   METHOD :
CC   -------
CC     Read on unit numsa1 the interpolated Levitus salinity onto 
CC     the global grid.
CC     Data begin at january. 
CC     The value is centered at the middle of month.
CC     In the opa model, kt=1 agree with january 1.
CC     At each time step, a linear interpolation is applied between 
CC     two monthly values.
CC
CC   METHOD :
CC   -------
CC     Read on unit numsa1
CC
CC   INPUT :
CC   -----
CC      argument
CC              kt              : time step
CC
CC   OUTPUT :
CC   ------
CC      argument                : no
CC      common
CC            /COMDTR/          : data salinity read
CC
CC   WORKSPACE :
CC   ---------
CC      local
CC            jpmois,jpf,ji,jj,jk,jl,ios,imois
CC            iman              : number of dates in data file 
CC                                (12 for a year of monthly values)
CC            iyy,imm,idd, i15  : year, month, day
CC            zxy               : coefficient for linear interpolation
CC                                in time
CC
CC   EXTERNAL :                   prihre
CC   --------
CC
CC   REFERENCES :        
CC   ----------
CC       Sydney Levitus
CC       climatological atlas of the world ocean
CC       NOAA professional paper 13, december 1982
CC
CC   MODIFICATIONS:
CC   --------------
CC       original  : 91-03 ()
CC       additions : 92-07 (M. Imbard)
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
#if defined key_mpp || defined key_fdir
c no ioipsl
#include "dtasal.monthly.mpp.h"
#    else
CDIR$ NOLIST
      USE ioipsl
#include "parameter.h"
#include "common.h"
CDIR$ LIST
C
      INTEGER kt
#    ifdef key_saldta
CC----------------------------------------------------------------------
      INTEGER jpmois,jpf
      PARAMETER (jpmois=12,jpf=1)
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER ji,jj,jk,jl
      INTEGER imois,iman
      INTEGER iyy,imm,idd,i15
      REAL zxy
      INTEGER istep(jpmois),itime
      REAL zlon(jpi,jpj),zlat(jpi,jpj),zlev(jpk),zdate0
      INTEGER ipi,ipj,ipk
      CHARACTER*32 clname
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (15/11/96)
CCC---------------------------------------------------------------------
C
C
C 0. Initialization
C -----------------
C
      iman  = jpmois
      iyy = ndastp/10000
      imm = (ndastp - iyy*10000)/100
      idd = (ndastp - iyy*10000 - imm*100)
      i15 = idd/16

      imois = imm + i15 - 1
      IF(imois == 0) imois = iman
      itime = jpmois
      ipi = jpi
      ipj = jpj
      ipk = jpk
C
C
C 1. First call kt=nit000
C -----------------------
C
      IF (kt == nit000 .AND. nlecsa == 0 ) THEN
          nsal1 = 0
          IF(lwp) THEN
              WRITE(numout,*)
              WRITE(numout,*) ' Levitus monthly fields'
              WRITE(numout,*) ' ----------------------'
              WRITE(numout,*) ' NetCDF FORMAT'
              WRITE(numout,*)
          ENDIF
C
C OPEN FILE
C
          clname = 'LEVITUS_1m_Salinity_Ice_nomask'
          CALL flinopen(TRIM(clname),nizoom,jpi,njzoom,jpj,.FALSE.
     $        ,ipi,ipj,ipk,zlon,zlat,zlev,itime,istep,zdate0,rdt,numsa1)
C
C title, dimensions and tests
C
          IF(itime /= jpmois) THEN
              IF(lwp) THEN
                  WRITE(numout,*) ' '
                  WRITE(numout,*) 'problem with time coordinates'
                  WRITE(numout,*) ' itime ',itime,' jpmois ',jpmois
              ENDIF 
              STOP 'dtasal.monthly'
          ENDIF
          IF(ipi /= jpidta .AND. ipj /= jpjdta .AND. ipk /= jpk)
     $        THEN
              IF(lwp) THEN
                  WRITE(numout,*) ' '
                  WRITE(numout,*) 'problem with dimensions'
                  WRITE(numout,*) ' ipi ',ipi,' jpidta ',jpidta
                  WRITE(numout,*) ' ipj ',ipj,' jpjdta ',jpjdta
                  WRITE(numout,*) ' ipk ',ipk,' jpk ',jpk
              ENDIF 
              STOP 'dtasal.monthly'
          ENDIF
          IF(lwp)WRITE(numout,*) itime,istep,zdate0,rdt,numsa1
C
      ENDIF
C
C
C 2. Read montly file
C -------------------
C
      IF ( ( kt == nit000 .AND. nlecsa == 0) .OR. imois /= nsal1) THEN
          nlecsa=1
C
C 2.1 Calendar computation
C
C nsal1 number of the first file record used in the simulation
C nsal2 number of the last  file record
C
          nsal1 = imois
          nsal2 = nsal1 + 1
          nsal1 = MOD( nsal1, iman )
          IF( nsal1 == 0 ) nsal1 = iman
          nsal2 = MOD( nsal2, iman )
          IF( nsal2 == 0 ) nsal2 = iman
          IF(lwp)WRITE(numout,*) 'first record file used nsal1 ',nsal1
          IF(lwp)WRITE(numout,*) 'last  record file used nsal2 ',nsal2
C
C 2.3 Read montly salinity data Levitus 
C
          itime=jpmois
          CALL flinget(numsa1,'vosaline',jpidta,jpjdta,jpk,itime,nsal1,
     $        nsal1,nizoom,jpi,njzoom,jpj,saldta(:,:,:,1))
          CALL flinget(numsa1,'vosaline',jpidta,jpjdta,jpk,itime,nsal2,
     $        nsal2,nizoom,jpi,njzoom,jpj,saldta(:,:,:,2))
C
          IF(lwp) THEN
              WRITE(numout,*) ' '
              WRITE(numout,*) ' read Levitus salinity ok'
              WRITE(numout,*) ' '
          ENDIF
C
C 2.4 Masks
C
#if defined key_orca_r2 && defined key_tradmp
C
C   ... Reduced salinity at Alboran Sea
          IF ( ndmp == -1 ) THEN 
              DO jj = kfindj0(101), kfindj1(109)
                DO ji = kfindi0(141), kfindi1(155)
                  DO jk = 13, 13
                    saldta(ji,jj,jk,:) = saldta(ji,jj,jk,:) - 0.15
                  END DO
                  DO jk = 14, 15
                    saldta(ji,jj,jk,:) = saldta(ji,jj,jk,:) - 0.25
                  END DO
                  DO jk = 16, 17
                    saldta(ji,jj,jk,:) = saldta(ji,jj,jk,:) - 0.30
                  END DO
                  DO jk = 18, 25
                    saldta(ji,jj,jk,:) = saldta(ji,jj,jk,:) - 0.35
                  END DO
                END DO
              END DO
          ENDIF
#endif
C
C   ... Mask
          DO jl = 1, 2
            saldta(:,:,:,jl) = saldta(:,:,:,jl)*tmask(:,:,:)
            saldta(:,:,jpk,jl) = 0.
          END DO  
C
C
          IF(lwp) THEN
              WRITE(numout,*)' salinity Levitus month ',nsal1,nsal2
              WRITE(numout,*)
              WRITE(numout,*) ' Levitus mounth = ',nsal1,'  level = 1'
              CALL prihre(saldta(1,1,1,1),jpi,jpj,1,jpi,20,
     $            1,jpj,20,1.,numout)
              WRITE(numout,*) ' Levitus mounth = ',nsal1,'  level = ',
     $            jpk/2
              CALL prihre(saldta(1,1,jpk/2,1),jpi,jpj,1,jpi,20,
     $            1,jpj,20,1.,numout)
              WRITE(numout,*) ' Levitus mounth = ',nsal1,'  level = ',
     $            jpkm1
              CALL prihre(saldta(1,1,jpkm1,1),jpi,jpj,1,jpi,20,
     $            1,jpj,20,1.,numout)
          ENDIF
      ENDIF
C
C 
C 3. At every time step compute salinity data
C -------------------------------------------
C
      zxy = FLOAT(idd + 15 - 30*i15)/30.
      sdta(:,:,:)= ( (1.-zxy)*saldta(:,:,:,1) + zxy*saldta(:,:,:,2) )
C
#    endif
#endif
