CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/dtatem.F,v 1.1.1.1.6.1 2002/02/04 13:45:16 maisonna Exp $
CDIR$ LIST
      SUBROUTINE dtatem ( kt )
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE dtatem
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC     Reads temperature data (Levitus monthly data)
CCC                             =======
CCC
CC   Method :
CC   -------
CC     Read on unit numte1 the interpolated Levitus temperature onto 
CC     the global grid.
CC     Data begin at january. 
CC     The value is centered at the middle of month.
CC     In the opa model, kt=1 agree with january 1.
CC     At each time step, a linear interpolation is applied between 
CC     two monthly values.
CC     Read on unit numte1
CC
CC   Input :
CC   ------
CC      argument
CC              kt              : time step
CC
CC   Output :
CC   -------
CC      common
CC            /comdtr/          : data temperature read
CC
CC   External :       prihre
CC   ---------
CC
CC   References :        
CC   -----------
CC       Sydney Levitus, climatological atlas of the world ocean
CC       NOAA professional paper 13, december 1982
CC
CC   Modifications :
CC   --------------
CC       original  : 91-03 ()
CC       additions : 92-07 (M. Imbard)
CC                 : 99-10 NetCDF FORMAT (M.A. Foujols, M. Imbard)
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
#if defined key_mpp || defined key_fdir
c no ioipsl
#include "dtatem.mpp.h"
#    else
CDIR$ NOLIST
      USE ioipsl
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER kt
#if defined key_temdta
      INTEGER jpmois, jpf, jl
      PARAMETER (jpmois=12,jpf=1)
      INTEGER imois, iman
      INTEGER iyy, imm, idd, i15
      CHARACTER*38 clname
      INTEGER istep(jpmois),itime
      REAL zlon(jpi,jpj),zlat(jpi,jpj),zlev(jpk)
     $    ,zdate0
      INTEGER ipi,ipj,ipk
      REAL zxy
#  if defined key_orca_r2 && defined key_tradmp
      INTEGER ji, jj, jk
#  endif
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (1997)
CCC---------------------------------------------------------------------
C
C
C 0. Initialization
C -----------------
C
      iman  = jpmois
      iyy = ndastp/10000
      imm = (ndastp - iyy*10000)/100
      idd = (ndastp - iyy*10000 - imm*100)
      i15 = idd/16
      imois = imm + i15 - 1
      IF(imois.eq.0) imois = iman
      itime = jpmois
      ipi = jpi
      ipj = jpj
      ipk = jpk
C
C
C 1. First call kt=nit000
C -----------------------
C
      IF ( kt.EQ.nit000.and.nlecte.eq.0 ) THEN
          ntem1=0
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*) ' Levitus monthly fields'
          IF(lwp)WRITE(numout,*) ' ----------------------'
          IF(lwp)WRITE(numout,*) ' NetCDF FORMAT'
          IF(lwp)WRITE(numout,*)
C
C OPEN FILE
C
          clname = 'LEVITUS_1m_Temperature_Pot_Ice_nomask '
          CALL flinopen(TRIM(clname),nizoom,jpi,njzoom,jpj,.false.,
     $        ipi,ipj,ipk,zlon,zlat,zlev,itime,istep,zdate0,rdt,numte1)
C
C title, dimensions and tests
C
          IF(itime .ne. jpmois) THEN
              IF(lwp) THEN
                  WRITE(numout,*) ' '
                  WRITE(numout,*) 'problem with time coordinates'
                  WRITE(numout,*) ' itime ',itime,' jpmois ',jpmois
              ENDIF 
              STOP 'dtatem'
          ENDIF
          IF(ipi .ne. jpidta .and. ipj .ne. jpjdta .and. ipk .ne. jpk)
     $        THEN
              IF(lwp) THEN
                  WRITE(numout,*) ' '
                  WRITE(numout,*) 'problem with dimensions'
                  WRITE(numout,*) ' ipi ',ipi,' jpidta ',jpidta
                  WRITE(numout,*) ' ipj ',ipj,' jpjdta ',jpjdta
                  WRITE(numout,*) ' ipk ',ipk,' jpk ',jpk
              ENDIF 
              STOP 'dtatem'
          ENDIF
          IF(lwp)WRITE(numout,*) itime,istep,zdate0,rdt,numte1
C
      ENDIF
C
C
C 2. Read montly file
C -------------------
C
      IF (( kt.EQ.nit000 .AND. nlecte .EQ. 0) .OR.
     $                              imois.NE.ntem1 ) THEN
          nlecte=1
C
C 2.1 Calendar computation
C
C ntem1 number of the first file record used in the simulation
C ntem2 number of the last  file record
C
          ntem1 = imois
          ntem2 = ntem1+1
          ntem1 = mod( ntem1, iman )
          IF ( ntem1.EQ.0 ) ntem1 = iman
          ntem2 = mod( ntem2, iman )
          IF ( ntem2.EQ.0 ) ntem2 = iman
          IF(lwp)WRITE(numout,*) 'first record file used ntem1 ', ntem1
          IF(lwp)WRITE(numout,*) 'last  record file used ntem2 ', ntem2
C
C 2.3 Read montly temperature data Levitus 
C
          itime=jpmois
          CALL flinget(numte1,'votemper',jpidta,jpjdta,jpk,itime,ntem1,
     $        ntem1,nizoom,jpi,njzoom,jpj,temdta(:,:,:,1))
          CALL flinget(numte1,'votemper',jpidta,jpjdta,jpk,itime,ntem2,
     $        ntem2,nizoom,jpi,njzoom,jpj,temdta(:,:,:,2))
C
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*) ' read Levitus temperature ok'
          IF(lwp)WRITE(numout,*)
C
C 2.4 Masks
C
#if defined key_orca_r2 && defined key_tradmp
C
C   ... Reduced temperature at Alboran Sea
          IF ( ndmp == -1 ) THEN 
              DO jj = kfindj0(101), kfindj1(109)
                DO ji = kfindi0(141), kfindi1(155)
                  DO jk = 13, 13
                    temdta(ji,jj,jk,:) = temdta(ji,jj,jk,:) - 0.20
                  END DO
                  DO jk = 14, 15
                    temdta(ji,jj,jk,:) = temdta(ji,jj,jk,:) - 0.35
                  END DO
                  DO jk = 16, 25
                    temdta(ji,jj,jk,:) = temdta(ji,jj,jk,:) - 0.40
                  END DO
                END DO
              END DO
C
C   ... Reduced temperature at Red Sea
              DO jj = kfindj0(87), kfindj1(96)
                DO ji = kfindi0(148), kfindi1(160)
                  DO jk = 4, 10
                    temdta(ji,jj,jk,:) = 7.0 
                  END DO
                  DO jk = 11, 13
                    temdta(ji,jj,jk,:) = 6.5 
                  END DO
                  DO jk = 14, 20
                    temdta(ji,jj,jk,:) = 6.0
                  END DO
                END DO                   
              END DO
          ENDIF
#endif
C
C   ... Mask
           DO jl = 1, 2
             temdta(:,:,:,jl) = temdta(:,:,:,jl)*tmask(:,:,:)
             temdta(:,:,jpk,jl) = 0.
           END DO  
C
C
          IF(lwp) THEN
              WRITE(numout,*)' temperature Levitus month ',ntem1,ntem2
              WRITE(numout,*)
              WRITE(numout,*) ' Levitus mounth = ',ntem1,'  level = 1'
              CALL prihre( temdta(1,1,1,1), jpi, jpj, 1, jpi, 20,
     $                     1, jpj, 20, 1., numout )
              WRITE(numout,*) ' Levitus mounth = ',ntem1,'  level = ',
     $            jpk/2
              CALL prihre( temdta(1,1,jpk/2,1), jpi, jpj, 1, jpi, 20,
     $                     1, jpj, 20, 1., numout )
              WRITE(numout,*) ' Levitus mounth = ',ntem1,'  level = ',
     $            jpkm1
              CALL prihre( temdta(1,1,jpkm1,1), jpi, jpj, 1, jpi, 20,
     $                     1, jpj, 20, 1., numout )
          ENDIF
      ENDIF
C
C 
C 2. At every time step compute temperature data
C ----------------------------------------------
C
      zxy = FLOAT( idd + 15 - 30 * i15 ) / 30.
      tdta(:,:,:)= ( (1.-zxy)*temdta(:,:,:,1) + zxy*temdta(:,:,:,2) )
C
#else
C     No temperature data read
#endif
C
#endif
C
      RETURN
      END
