CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/dtrlec.F,v 1.1.1.1.6.3 2002/02/04 13:45:16 maisonna Exp $
CDIR$ LIST
      SUBROUTINE dtrlec 
CCC--------------------------------------------------------------------- 
CCC
CCC                       ROUTINE dtrlec
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC     Read files for restart
CCC
CC   Method :
CC   -------
CC      Read the previous fields on the file numrst
CC      the first record indicates previous characterics
CC      after control with the present run, we read :
CC      - prognostic variables on the second record
CC      - elliptic solver arrays 
CC	- barotropic stream function arrays (default option)
CC	  or free surface arrays ("key_freesurf_cstvol" defined)
CC      - tke arrays ("key_zdftke" defined)
CC      for this last three records,  the previous characteristics 
CC      could be different with those used in the present run. 
CC
CC   Input :
CC   ------
CC      common
CC            /comrst/          : restart parameter
CC            /comctl/          : parameters for the control
CC
CC   Output :
CC   -------
CC      common
CC            /combef/          : previous fields (before)
CC            /comnow/          : present fields (now)
CC            /combsf/          : barotropic stream function
CC            /comspg/          : surface pressure 
CC            /comsol/          : diagonal preconditioned conjugate
CC
CC   Modifications :
CC   --------------
CC      original  : 91-03 ()
CC      additions : 92-01 (M. Imbard)
CC                : 92-06 correction restart file (M. Imbard)
CC                : 98-02 (M. Guyon) FETI method
CC      addition  : 98-05 (G. Roullet) free surface
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
#if defined key_mpp || defined key_fdir
c no ioipsl
#include "dtrlec.mpp.h"
#    else
CDIR$ NOLIST
      USE ioipsl
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER ino0, it0, ipcg0, isor0, itke0
      INTEGER ino1, it1, isor1, ipcg1, itke1, idast1
      INTEGER itime, ibvar
      REAL zdate0, zdt, zinfo(6)
      REAL zdept(jpk),zlamt(jpi,jpj),zphit(jpi,jpj)
      CHARACTER*32 clname,cln
      LOGICAL clog, clbon
      CHARACTER*8 clvnames(30)
#if defined key_ice_lln
      INTEGER ios, ji, jj, jl, jn
      REAL zfice
#endif
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (1997)
CCC---------------------------------------------------------------------
C
C
C 0. Initialisations
C ------------------
C
      ino0  = no
      it0   = nit000
      ipcg0 = 0
      isor0 = 0
      itke0 = 0
      isor0 = nsolv-1
      ipcg0 = 2-nsolv
#ifdef key_zdftke
      itke0 = 1
#endif
C FETI method
      IF (nsolv .EQ. 3) THEN 
          isor0=2
          ipcg0=2
      ENDIF 
C
      IF(lwp) THEN
          WRITE(numout,*) ' '
          WRITE(numout,*) ' *** dtrlec:  beginning of restart'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' the present run :'
          WRITE(numout,*) '   job number : ', no 
          WRITE(numout,*) '   with nit000 : ', nit000
          WRITE(numout,*) '   with pcg option ipcg0 : ', ipcg0
          WRITE(numout,*) '   with sor option isor0 : ', isor0
          WRITE(numout,*) '   with FETI solver option ipcg0 & isor0 : ',
     $        ipcg0,' & ',isor0
          WRITE(numout,*) '   with tke option itke0 : ', itke0
      ENDIF
C
C 1. Read numrst
C --------------
C
C ... First 
C
      clname='orcaini'
      cln='orcaini.nc'
      INQUIRE (FILE=cln,EXIST=clbon)
      IF (.NOT.clbon) THEN
          clname='restart'
      ENDIF
C
      itime=0
      clog=.false.
      zlamt(:,:)=0.
      zphit(:,:)=0.
      zdept(:)=0.
      CALL restini(clname,jpi,jpj,zlamt,zphit,jpk,zdept,clname
     $    ,itime,zdate0,zdt,numrst)
C
      CALL ioget_vname(numrst, ibvar, clvnames)
      CALL restget(numrst,'info',1,1,6,0,clog,zinfo)
      ino1  = nint(zinfo(1))
      it1   = nint(zinfo(2))
      ipcg1 = nint(zinfo(3))
      isor1 = nint(zinfo(4))
      itke1 = nint(zinfo(5))
      idast1= nint(zinfo(6))
      IF(lwp) THEN
          WRITE(numout,*) ' '
          WRITE(numout,*) ' READ numrst with '
          WRITE(numout,*) '   job number : ', ino1
          WRITE(numout,*) '   with time step it : ', it1
          WRITE(numout,*) '   with pcg option ipcg1 : ', ipcg1
          WRITE(numout,*) '   with sor option isor1 : ', isor1
          WRITE(numout,*) '   with tke option itke1 : ', itke1
          WRITE(numout,*) '   with FETI solver option ipcg1 + isor1 : ',
     $        ipcg1 + isor1
          WRITE(numout,*) '   with FILE name : ', clname
          WRITE(numout,*) '   number of variables   : ', ibvar
          WRITE(numout,*) '   NetCDF variables      : '
          WRITE(numout,*) ' ',clvnames
          WRITE(numout,*) ' '
      ENDIF
C
C ... Control of date
C
      IF ( (it0-it1).NE.1 .AND. abs(nrstdt).EQ.1 ) THEN
          IF(lwp) THEN
              WRITE(numout,*) ' ===>>>> : problem with nit000 for the',
     $            ' restart'
              WRITE(numout,*) ' =======                              ',
     $            ' ======='
              WRITE(numout,*) ' we stop. verify the file'
              WRITE(numout,*) ' or rerun with the value  0 for the'
              WRITE(numout,*) ' control of time parameter  nrstdt'
              WRITE(numout,*) ' '
          ENDIF
          STOP 'dtrlec'
      ENDIF
      IF ( nrstdt.EQ.1 ) ndate0 = idast1
C
C ... Read prognostic variables
C
      CALL restget(numrst,'ub',jpi,jpj,jpk,0,clog,ub)
      CALL restget(numrst,'vb',jpi,jpj,jpk,0,clog,vb)
      CALL restget(numrst,'tb',jpi,jpj,jpk,0,clog,tb)
      CALL restget(numrst,'sb',jpi,jpj,jpk,0,clog,sb)
      CALL restget(numrst,'rotb',jpi,jpj,jpk,0,clog,rotb)
      CALL restget(numrst,'hdivb',jpi,jpj,jpk,0,clog,hdivb)
      CALL restget(numrst,'un',jpi,jpj,jpk,0,clog,un)
      CALL restget(numrst,'vn',jpi,jpj,jpk,0,clog,vn)
      CALL restget(numrst,'tn',jpi,jpj,jpk,0,clog,tn)
      CALL restget(numrst,'sn',jpi,jpj,jpk,0,clog,sn)
      CALL restget(numrst,'rotn',jpi,jpj,jpk,0,clog,rotn)
      CALL restget(numrst,'hdivn',jpi,jpj,jpk,0,clog,hdivn)
#if defined key_ice_lln
      CALL restget(numrst,'tn_ice',jpi,jpj,1,0,clog,tn_ice)
      CALL restget(numrst,'alb_ice',jpi,jpj,1,0,clog,alb_ice)
#if defined key_coupled
      CALL restget(numrst,'sstmoyb',jpi,jpj,1,0,clog,sstmoy(:,:,1))
      CALL restget(numrst,'sstmoyn',jpi,jpj,1,0,clog,sstmoy(:,:,2))
#endif
#endif
C
C ... Read elliptic solver arrays
C
      CALL restget(numrst,'gcxb',jpi,jpj,1,0,clog,gcxb)
      CALL restget(numrst,'gcx',jpi,jpj,1,0,clog,gcx)
C
#ifdef key_freesurf_cstvol
C
C ... free surface formulation (eta)
C
      CALL restget(numrst,'etab',jpi,jpj,1,0,clog,etab)
      CALL restget(numrst,'etan',jpi,jpj,1,0,clog,etan)
#  else
C
C ... Rigid-lid formulation (bsf)
C
      CALL restget(numrst,'bsfb',jpi,jpj,1,0,clog,bsfb)
      CALL restget(numrst,'bsfn',jpi,jpj,1,0,clog,bsfn)
      CALL restget(numrst,'bsfd',jpi,jpj,1,0,clog,bsfd)
#endif
C
#ifdef key_zdftke
C
C ... Read tke arrays
C
      IF(itke1.eq.1) THEN
          CALL restget(numrst,'en',jpi,jpj,jpk,0,clog,en)
      ELSE
          IF(lwp) THEN
              WRITE(numout,*) ' ===>>>> : the previous restart file',
     $            ' didnt used  tke scheme'
              WRITE(numout,*) ' =======                ======='
          ENDIF
          nrstdt=2
      ENDIF
#endif
C
C ... Louvain La Neuve Sea Ice Model
#if defined key_ice_lln
      ios = 0
      DO jn = 1, 30
        IF(clvnames(jn) .eq. 'sbcocn') ios=1
      END DO
      IF ( ios.eq.1 ) then
          CALL restget(numrst,'sbcocn',jpi,jpj,10,0,clog,sbcocn)
          zfice=sbcocn(1,1,1)
      ENDIF
      IF(zfice.ne.FLOAT(nfice).OR.ios.eq.0) THEN 
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*) 'dtrlec - LLN sea Ice Model'
          IF(lwp)WRITE(numout,*) 'Ice initialization'
          IF(lwp)WRITE(numout,*)
C 
          DO jl = 1, 10
            DO jj = 1, jpj
              DO ji = 1, jpi
                sbcocn(ji,jj,jl) = 0.
              END DO
            END DO
          END DO      
          DO jj = 1, jpj
            DO ji = 1, jpi
              sbcocn(ji,jj,6) = sbcocn(ji,jj,6)
     $                        + ( nfice-1 )*( tn(ji,jj,1)+rt0 )
              sbcocn(ji,jj,7) = sbcocn(ji,jj,7)
     $                        + ( nfice-1 )*  sn(ji,jj,1)
            END DO
          END DO  
          DO jj = 2, jpj
            DO ji = 2, jpi
              sbcocn(ji,jj,8) = sbcocn(ji,jj,8)
     $                 + (nfice-1)*0.5*( un(ji-1,jj,1)+un(ji-1,jj-1,1) )
              sbcocn(ji,jj,9) = sbcocn(ji,jj,9)
     $                 + (nfice-1)*0.5*( vn(ji,jj-1,1)+vn(ji-1,jj-1,1) )
            END DO
          END DO
      ENDIF 
#endif
C
      CALL restclo(numrst)
C
#endif
C
      RETURN
      END
