CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/flxrnf.F,v 1.1.1.1.6.2 2002/02/04 13:45:22 maisonna Exp $
CDIR$ LIST
      SUBROUTINE flxrnf ( kt )
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE flxrnf
CCC                     ******************
CCC  ORCA version 13/07/2000
CCC
CCC  Purpose :
CCC  --------
CCC     Introduce a climatological run off forcing
CCC
CCC	C a u t i o n : upward water flux, runoff is negative
CCC			set at the last loop of the routine
CCC
CC   Method :
CC   -------
CC      Initialze each mouth of river with a monthly climatology 
CC      provided from different data.
CC
CC   Input : 
CC   ------
CC      argument
CC              kt              : time step
CC
CC   Output :
CC   -------
CC      common
CC            /cimrnf/ numrof  : logical unit for runoff data
CC                     numrof  : logical unit for runoff data
CC                     nrunoff : runoff option (namelist)
CC                     nrnf1, nrnf2  : first and second record used
CC            /comrdr/ rnfdta  : monthly runoff data array (kg/m2/s)
CC            /comrnf/ runoff  : runoff data a given time-step (kg/m2/s)
CC                     coefr   : coeff of advection link to runoff
CC
CC   References : 
CC   -----------
CC       J. D. Milliman and R. H. Meade, 1983 : world-wide delivery
CC          of river sediment to the oceans, journal of geology vol 91
CC          pp 1-21.
CC       G. L. Russell and J. R. Miller, 1990 : global river runoff
CC          calculated from a global atmospheric general circulation
CC          model, journal of hydrology, 117(1990), pp 241-254.
CC       F. Van Der Leeden, Troise F. L., Todd D. K. : the water
CC          encyclopedia, second edition, lewis publishers.
CC       J. W. Weatherly, J. E. Walsh : The effects of precipitation
CC          and river runoff in a coupled ice-ocean model of Arctic
CC          Climate dynamics 1996 12:785,798
CC	Jacobs et al. 1992. J. Glaciol. 38 (130) 375-387.
CC
CC   Modifications :
CC   --------------
CC       original  : 10/94 (G.Madec, M. Pontaud, M. Imbard)
CC       additions :  3/97 (G.Madec) time dependent version
CC                   06/98 (J.M. Molines) : exact computation of zxy 
CC                         for months that are not 30 days
CC                   07/98 (M. Imbard) ORCA and mpp option
CC                   08/99 (J.P. Boulanger H.L.Ayina): New rivers and 
CC                         values given in m3/s 
CC                   04/00 (G. Madec, K. Roberts) add antarctica ice
CC			   discharge.
CC                   11/00 (R. Hordoir, E. Durand) NetCDF FORMAT
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CDIR$ NOLIST
      USE ioipsl
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC Local declarations
CC ==================
      INTEGER kt
CC
#if defined key_orca_r05
#  if defined key_coupled
      runoff(:,:) = 0.0e0
#  else
#    include "flxrnf.orca.r05.h"
#  endif
#endif
#if defined key_orca_r025
#  if defined key_coupled
      runoff(:,:) = 0.0e0
#  else
      IF(lwp)WRITE(numout,*) '!!!!!!!!!!!!!!!!!!!!!!!!!!!!'
      IF(lwp)WRITE(numout,*) 'flxrnf ORCA_R025 NOT yet implemented'
      IF(lwp)WRITE(numout,*) '^^^^^^^^^^^^^^^^^^^^^^^^^^^^'
#  endif
#endif
#if ( defined key_orca_r2 || defined key_orca_r4 )
#  if ! defined key_coupled
      INTEGER iyy, imm, idd, i15, imois, iman
      INTEGER idbd, idmeom
      REAL zxy
#  endif
      INTEGER, PARAMETER :: jpmois = 12
      INTEGER istep(jpmois)
      INTEGER ipi,ipj,ipk,itime
      CHARACTER*32 clname
      REAL zlon(jpi,jpj),zlat(jpi,jpj),zlev(jpk),zdate0
      REAL zcoefr(jpi,jpj)
      INTEGER ji, jj
C
CC
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (1997)
CCC---------------------------------------------------------------------
C
      IF (kt == nit000) THEN
          IF(lwp)WRITE(numout,*) ' '
          IF(lwp)WRITE(numout,*) 'Subroutine flxrnf.F'
          IF(lwp)WRITE(numout,*) '-------------------'
          IF(lwp)WRITE(numout,*) 'nrunoff = ',nrunoff
C
          IF (nrunoff == 0) THEN
             IF(lwp)WRITE(numout,*) ' '
             IF(lwp)WRITE(numout,*) 'No runoff in this simulation'
             IF(lwp)WRITE(numout,*) ' '
          ENDIF
          IF (nrunoff == 1) THEN
             IF(lwp)WRITE(numout,*) ' '
             IF(lwp)WRITE(numout,*) 'Simulation with runoff only'
             IF(lwp)WRITE(numout,*) ' '
          ENDIF
          IF (nrunoff == 2) THEN
             IF(lwp)WRITE(numout,*) ' '
             IF(lwp)WRITE(numout,*) 'Simulation with runoff + advection'
             IF(lwp)WRITE(numout,*) ' '
          ENDIF
C ... Set runoffs and upstream coeff to zero at first timestep
          runoff (:,:) = 0.e0
          upsrnfh(:,:) = 0.e0
          upsrnfz(:) = 0.e0
C
      ENDIF
C
C
C 1. Initialization
C -----------------
C
      IF (nrunoff == 1 .OR. nrunoff == 2) THEN
#  if ! defined key_coupled
C
C ... year, month, day
C
          iman = jpmois
          iyy = ndastp/10000
          imm = (ndastp - iyy*10000)/100
          idd = (ndastp - iyy*10000 - imm*100)
          i15 = idd/16
          imois = imm + i15 - 1
          IF(imois == 0) imois = iman
C   ... Number of days in the month
          IF (nbisex == 1 .AND. MOD( iyy, 4 ) == 0) THEN
              idbd = nbiss(imois)
          ELSEIF (nbisex > 1) THEN
              idbd = nbisex
          ELSE
              idbd = nobis(imois)
          END IF
C   ... Number of days between imois, 15 and the end of month
          idmeom = idbd - 15
#  endif
          ipi = jpi
          ipj = jpj
          ipk = jpk
          itime=jpmois
C
C ... Open file
C
          IF (kt == nit000) THEN
              clname='runoff_1m_nomask' 
              CALL flinopen(clname,nizoom,jpi,njzoom,jpj,.false.,ipi,ipj
     $            ,ipk,zlon,zlat,zlev,itime,istep,zdate0,rdt,numrof) 
C   ... Title, dimensions and tests
#  if ! defined key_coupled
              IF(itime /= jpmois) THEN
                  IF(lwp)WRITE(numout,*) ' '
                  IF(lwp)WRITE(numout,*) 'problem with time coordinates'
                  IF(lwp)WRITE(numout,*) ' itime ',itime,' jpmois ',jpmois
                  STOP 'flxrnf.F'
              ENDIF
              IF(lwp)WRITE(numout,*) itime,istep,zdate0,rdt,numrof
              IF(lwp)WRITE(numout,*) 'numrof=', numrof
              IF(lwp)WRITE(numout,*) 'jpmois=', jpmois
              IF(lwp)WRITE(numout,*) 'rdt=', rdt
#  endif
              IF(ipi /= jpidta .and. ipj /= jpjdta .and. ipk /= 1) THEN
                  IF(lwp)WRITE(numout,*) ' '
                  IF(lwp)WRITE(numout,*) 'problem with dimensions'
                  IF(lwp)WRITE(numout,*) ' ipi ',ipi,' jpidta ',jpidta
                  IF(lwp)WRITE(numout,*) ' ipj ',ipj,' jpjdta ',jpjdta
                  IF(lwp)WRITE(numout,*) ' ipk ',ipk,' =? 1'
                  STOP 'flxrnf.F'
              ENDIF
              IF(lwp)WRITE(numout,*) 'ipi=', ipi,' ipj=',ipj,' ipk=',ipk
          ENDIF
C
#  if ! defined key_coupled
C
C 2. Read monthly file of runoff
C ------------------------------
C
          IF ( kt == nit000 .OR. imois /= nrnf1 ) THEN
C
C ... Calendar computation for interpolation
C     nrnf1 number of the first array record used in the simulation
C     nrnf2 number of the last  array record
C
              nrnf1=imois
              nrnf2=nrnf1+1
              nrnf1=mod(nrnf1,iman)
              IF(nrnf1 == 0) nrnf1=iman
              nrnf2=mod(nrnf2,iman)
              IF(nrnf2 == 0) nrnf2=iman
              itime=jpmois
C
              IF(lwp) THEN
                  WRITE(numout,*) ' '
                  WRITE(numout,*) ' runoff monthly field'
                  WRITE(numout,*) ' --------------------'
                  WRITE(numout,*) ' NetCDF format'
                  WRITE(numout,*) ' '
                  WRITE(numout,*) 'first array record used nrnf1 ',nrnf1
                  WRITE(numout,*) 'last  array record used nrnf2 ',nrnf2
                  WRITE(numout,*) ' '
              ENDIF
C
C ... Read monthly runoff data in kg/m2/s
C
              CALL flinget(numrof,'sorunoff',jpidta,jpjdta,1,itime
     $            ,nrnf1,nrnf1,nizoom,jpi,njzoom,jpj,rnfdta(:,:,1))
              CALL flinget(numrof,'sorunoff',jpidta,jpjdta,1,itime
     $            ,nrnf2,nrnf2,nizoom,jpi,njzoom,jpj,rnfdta(:,:,2))
C
              IF(lwp)WRITE(numout,*) ' '
              IF(lwp)WRITE(numout,*) ' read runoff field ok'
              IF(lwp)WRITE(numout,*) ' '
C
          ENDIF
C
C ... Linear interpolation and conversion in upward water flux
C     C a u t i o n : runoff is negative and in kg/m2/s 
C
          zxy = FLOAT( idd + idmeom - idbd * i15 ) / idbd
C
          runoff(:,:) = -( (1.-zxy)*rnfdta(:,:,1) + zxy*rnfdta(:,:,2) )
C
C  Runoff reduction
          DO jj = 1, jpj
            DO ji = 1, jpi
              IF ( gphit(ji,jj) > 40 .AND. gphit(ji,jj) < 65 ) THEN
                  runoff(ji,jj) = 0.85*runoff(ji,jj)
              ENDIF              
            END DO
          END DO
C
#  endif
C
      ENDIF
C
C
C 3. Mixed advection scheme 
C -------------------------
C
      IF (nrunoff == 2 .AND. kt == nit000) THEN
          itime=jpmois
C
C ... Upstream and centered scheme in the vicinity of river mouths
C
C  Creates the array coef that contains the coefficient to affect to
C  the upstream scheme. advection scheme will be:
C  coefr * upstream + (1- coefr) centered
C  coefr must be between 0 and 1.
C
          CALL flinget(numrof,'socoefr',jpidta,jpjdta,1,itime,nrnf1
     $        ,nrnf1,nizoom,jpi,njzoom,jpj,zcoefr(:,:))
C
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*) ' read coefr for advection ok'
          IF(lwp)WRITE(numout,*)
C
          upsrnfh(:,:) = zcoefr(:,:)
          upsrnfz(:)   = 0.e0
          upsrnfz(1)   = 0.5
          upsrnfz(2)   = 0.5
          upsrnfz(3)   = 0.5
          upsrnfz(4)   = 0.25
          upsrnfz(5)   = 0.125
C
C   ... Reduces the sea surface restoring term to Levitus98
C    in the Sound Strait
# if defined key_orca_r2
          DO jj = kfindj0(116), kfindj1(116)
            DO ji = kfindi0(144), kfindi1(144)
              upsrnfh(ji,jj) = 0.25
            END DO
            DO ji = kfindi0(145), kfindi1(147)
              upsrnfh(ji,jj) = 0.5
            END DO
            DO ji = kfindi0(148), kfindi1(148)
              upsrnfh(ji,jj) = 0.25
            END DO
          END DO
# endif
C
      ENDIF
C
C ... Upstream and centered scheme in the vicinity of some straits
C
C   ... Initialization
      upsadv(:,:) = 0.e0
C
# if defined key_orca_r2
C   ... ORCA_R2 configuration :
C     ... Gibraltar Strait
      DO jj = kfindj0(102), kfindj1(102)
        DO ji = kfindi0(138), kfindi1(138)
          upsadv(ji,jj) = 0.2
        END DO
      END DO
      DO jj = kfindj0(102), kfindj1(102)
        DO ji = kfindi0(139), kfindi1(139)
          upsadv(ji,jj) = 0.4
        END DO
      END DO
      DO jj = kfindj0(102), kfindj1(102)
        DO ji = kfindi0(140), kfindi1(140)
          upsadv(ji,jj) = 0.5
        END DO
      END DO
      DO jj = kfindj0(101), kfindj1(102)
        DO ji = kfindi0(141), kfindi1(141)
          upsadv(ji,jj) = 0.5
        END DO
      END DO
C   ... Bab el Mandeb Strait
      DO jj = kfindj0(87), kfindj1(88)
        DO ji = kfindi0(164), kfindi1(164)
          upsadv(ji,jj) = 0.1
        END DO
      END DO
      DO jj = kfindj0(88), kfindj1(88)
        DO ji = kfindi0(163), kfindi1(163)
          upsadv(ji,jj) = 0.25
        END DO
      END DO
      DO jj = kfindj0(88), kfindj1(88)
        DO ji = kfindi0(162), kfindi1(162)
          upsadv(ji,jj) = 0.4
        END DO
      END DO
      DO jj = kfindj0(88), kfindj1(88)
        DO ji = kfindi0(160), kfindi1(161)
          upsadv(ji,jj) = 0.5
        END DO
      END DO
      DO jj = kfindj0(89), kfindj1(89)
        DO ji = kfindi0(158), kfindi1(160)
          upsadv(ji,jj) = 0.25
        END DO
      END DO
      DO jj = kfindj0(90), kfindj1(90)
        DO ji = kfindi0(160), kfindi1(160)
          upsadv(ji,jj) = 0.25
        END DO
      END DO
C   ... Sound Strait
      DO jj = kfindj0(116), kfindj1(116)
        DO ji = kfindi0(145), kfindi1(147)
          upsadv(ji,jj) = 0.5
        END DO
      END DO
C
# elif defined key_orca_r4
C   ... ORCA_R4 configuration : Gibraltar Strait
      DO jj = kfindj0(52), kfindj1(53)
        DO ji = kfindi0(70), kfindi1(71)
          upsadv(ji,jj) = 0.5
        END DO
      END DO
# else
C     No specific mixed scheme
# endif
C
      
C 4. Closing all files
C --------------------
C
      IF ( kt == nitend .AND. nrunoff >= 1 ) THEN
          CALL flinclo(numrof)
      ENDIF
C
#endif
      RETURN
      END
