CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/icelln.F,v 1.1.1.1.6.3 2002/02/04 13:45:22 maisonna Exp $
CDIR$ LIST
      SUBROUTINE icelln(kt)
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE icelln
CCC                     ******************
CCC 
CCC  Purpose :
CCC  --------
CCC     CALL the Louvain la Neuve Sea Ice Model 
CCC
CC
CC   Modifications :
CC   --------------
CC      original  : 99-11 (M. Imbard)
CC      additions : 01-03 (D. Ludicone, E. Durand, G. Madec) free surf.
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER kt
#if defined key_ice_lln 
      INTEGER ji, jj
      REAL zdtsd2, ztx, ztaux, zty, ztauy, ztrp, zsrp, zerp
      REAL zwei
      REAL zerpplus(jpi,jpj), zerpminus(jpi,jpj)
      REAL zplus, zminus, zadefi
#if defined key_freesurf_cstvol
      REAL zdmp(jpi,jpj)
#  if defined key_tradmp
      INTEGER jk
      REAL zstrdmp(jpi,jpj)
#  endif
#endif
#if defined key_coupled 
      REAL zciobc(jpi,jpj,13)
      REAL ztdta, zqrp
#elif defined defined key_flx_lmd
      REAL zciobc(jpi,jpj,12)
      REAL ztdta, zqrp
#else
      REAL zciobc(jpi,jpj, 7)
#endif
      SAVE zciobc
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8.2, LODYC-IPSL (2001)
CCC---------------------------------------------------------------------
C
C>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
C
C Louvain-la-Neuve Sea Ice Model
C ==============================
C
C<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
c
c zciobc atmospheric variables
c sbcocn oceanic variables --> Ice model
c
#if defined key_coupled
C Coupled case
#  include "icelln.coupled.h"
C
#elif defined key_flx_lmd
C Forced by LMD fluxes case
#  include "icelln.lmd.h"
C 
#else
C Forced case
C
C Temperature and salinity
C
C C A U T I O N : sbcocn(:,:,6) and sbcocn(:,:,7) are initialized at 
C              at nit000 in inidtr.F (or dtrlec.F) with :
C              sbcocn(:,:,6) = sbcocn(:,:,6)+(nfice-1)*(tn(:,:,1)+rt0 )
C              sbcocn(:,:,7) = sbcocn(:,:,7)+(nfice-1)*sbcocn(:,:,7)
C
      sbcocn(:,:,6) = sbcocn(:,:,6) + tn(:,:,1) + rt0
      sbcocn(:,:,7) = sbcocn(:,:,7) + sn(:,:,1)
c
c vectors at F-point
c
      DO jj = 2, jpj
        DO ji = 2, jpi
          sbcocn(ji,jj,8) = sbcocn(ji,jj,8)
     $                    + 0.5*( un(ji-1,jj,1)+un(ji-1,jj-1,1) )
          sbcocn(ji,jj,9) = sbcocn(ji,jj,9)
     $                    + 0.5*( vn(ji,jj-1,1)+vn(ji-1,jj-1,1) )
        END DO
      END DO
C      
      IF( mod(kt-1,nfice) == 0 ) THEN
C
C The LIM model is going to be call
C
          zciobc(:,:,1) = watm(:,:)
          zciobc(:,:,2) = tatm(:,:)
          zciobc(:,:,3) = hatm(:,:)
          zciobc(:,:,6) = vatm(:,:)
          zciobc(:,:,7) = catm(:,:)
          DO jj = 2, jpj
            DO ji = 2, jpi
              zciobc(ji,jj,4) = 0.5*( taux(ji-1,jj) + taux(ji-1,jj-1) )
              zciobc(ji,jj,5) = 0.5*( tauy(ji,jj-1) + tauy(ji-1,jj-1) )
            END DO
          END DO
          CALL lbcice( zciobc(:,:,4), 4, 0, 1, 1 )
          CALL lbcice( zciobc(:,:,5), 4, 0, 1, 1 )
C
          sbcocn(:,:,1) = 0.e0
          sbcocn(:,:,2) = 0.e0
          sbcocn(:,:,3) = 0.e0
          sbcocn(:,:,4) = 0.e0
          sbcocn(:,:,5) = 0.e0
          sbcocn(:,:,10) = 0.e0
          sbcocn(:,:,6) = sbcocn(:,:,6)/FLOAT(nfice)
          sbcocn(:,:,7) = sbcocn(:,:,7)/FLOAT(nfice)
          DO jj = 2, jpj
            DO ji = 2, jpi
              sbcocn(ji,jj,8) = sbcocn(ji,jj,8)/FLOAT(nfice)
              sbcocn(ji,jj,9) = sbcocn(ji,jj,9)/FLOAT(nfice)
            END DO
          END DO
          CALL lbcice( sbcocn(:,:,8), 4, 0, 1, 1 )
          CALL lbcice( sbcocn(:,:,9), 4, 0, 1, 1 )
c
c Put data from ocean model to ice model
c
          CALL ocetoice( zciobc, sbcocn )
          IF ( nacc == 1 ) THEN 
              zdtsd2 = 0.5*rdtmin*nfice
          ELSE 
              zdtsd2 = 0.5*rdt*nfice
          ENDIF
c
c Ice model call
c
          CALL icemodel( raass, zdtsd2, nfice*rdttra(1) )
c
c From ice to ocean model
c
          CALL icetooce( sbcocn )
C
          CALL lbcice( sbcocn(:,:,1), 4, 0, 1, 1 )
          CALL lbcice( sbcocn(:,:,2), 4, 0, 1, 1 )
C 
          CALL lbc2  ( sbcocn(:,:,3), 1, 1, 1, 1, 1, 1 )
          CALL lbc2  ( sbcocn(:,:,4), 1, 1, 1, 1, 1, 1 )
          CALL lbc2  ( sbcocn(:,:,5), 1, 1, 1, 1, 1, 1 )
          CALL lbc2  ( sbcocn(:,:,6), 1, 1, 1, 1, 1, 1 )
          CALL lbc2  ( sbcocn(:,:,8), 1, 1, 1, 1, 1, 1 )
          CALL lbc2  ( sbcocn(:,:,9), 1, 1, 1, 1, 1, 1 )
          CALL lbc2  ( sbcocn(:,:,10), 1, 1, 1, 1, 1, 1 )
C
C
C Surface Ocean fluxes
C ====================
C
C
C Initialisation
C --------------
C
C ... Restoring coefficients on SST and SSS
C
          ztrp  = -40.                   ! (W/m2/K)    
          zsrp  = ztrp * ro0cpr * rauw   ! (Kg/m2/s2)  
C
C ... sea ice indicator (1 or 0)
#if defined key_ice_lln
          DO jj = 1, jpj
            DO ji = 1, jpi
              freezn(ji,jj) = MAX(0., SIGN(1., sbcocn(ji,jj,6)-rsmall))
            END DO
          END DO
#else
C         Computed in ocfrzpt.F
#endif
C
C
C Surface heat flux (W/m2)
C -----------------
C
C ... non solar heat flux + solar flux
          q  (:,:) = sbcocn(:,:,3) + sbcocn(:,:,5)
          qt (:,:) = q(:,:)
C
C ... solar flux
          qsr(:,:) = sbcocn(:,:,5)
C
C
C Surface freshwater flux (kg/m2/s)
C -----------------------
C
#if defined key_freesurf_cstvol 
C
C ... Free-surface
C
C   ... Internal damping
#    if defined key_tradmp
C     ... Vertical mean of dampind trend (computed in tradmp.F)
          zstrdmp(:,:) = 0.e0
          DO jk = 1, jpk
            DO jj = 1, jpj
              DO ji = 1, jpi
                zstrdmp(ji,jj) = zstrdmp(ji,jj)
     $                         + strdmp(ji,jj,jk) * fse3t(ji,jj,jk)
              END DO
            END DO
          END DO
C     ... volume flux associated to internal damping to climatology
          zdmp(:,:) = zstrdmp(:,:) * rauw / ( sbcocn(:,:,7) + rsmall )
#    else
C   ... No internal damping
          zdmp(:,:) = 0.e0
#    endif
C
C   ... Surface restoring term
          aplus  = 0.e0
          aminus = 0.e0
          zerpplus  (:,:) = 0.e0
          zerpminus (:,:) = 0.e0
          zplus  = 15./rday
          zminus = -15./rday
C
c          erp(:,:) = zsrp                        ! time scale
c     $             * ( 1.-O.3333*freezn(:,:) )   ! reduced below sea-ice
c     $             * ( 1.-2.*upsrnfh(:,:) )      ! not near river mouths
c     $             * ( sbcocn(:,:,7)-sdta(:,:,1))! Salinity difference
c     $             / ( sbcocn(:,:,7)+rsmall     )! convert in freshwater
C 
          DO jj = 1, jpj
            DO ji = 1, jpi
              zerp = ( 1. - 2.*upsrnfh(ji,jj) ) * zsrp
     $            * ( sbcocn(ji,jj,7) - sdta(ji,jj,1) )
     $            / ( sbcocn(ji,jj,7) + rsmall        )
C
              zerp = MIN( zerp, zplus  )
              zerp = MAX( zerp, zminus )
              erp(ji,jj) = zerp
              zerpplus(ji,jj)  = MAX( erp(ji,jj), 0.0 )
              zerpminus(ji,jj) = MIN( erp(ji,jj), 0.0 )
            END DO
          END DO
C
          DO jj = 2, jpj-2
            DO ji = 2, jpi-1
              zwei   = tmask(ji,jj,1) * e1t(ji,jj) * e2t(ji,jj)
              aplus  = aplus  + zerpplus(ji,jj)  * zwei
              aminus = aminus - zerpminus(ji,jj) * zwei
            END DO
          END DO
          jj = jpj-1
          DO ji = 2, (jpi-1)/2          
            zwei   = tmask(ji,jj,1) * e1t(ji,jj) * e2t(ji,jj)
            aplus  = aplus  + zerpplus(ji,jj)  * zwei
            aminus = aminus - zerpminus(ji,jj) * zwei            
          END DO
C          
          zadefi = MIN( aplus, aminus )
          IF ( zadefi == 0.0 ) THEN 
              erp(:,:) = 0.e0
          ELSE
              erp(:,:) = zadefi
     $             * ( zerpplus(:,:)/aplus + zerpminus(:,:)/aminus )
          ENDIF
C
C ... total concentration/dilution effect (use on SSS)
          emps(:,:) = sbcocn(:,:,10) + sbcocn(:,:,4) 
     $              + runoff(:,:) + erp(:,:) + empold
C
C ... total volume flux (use on sea-surface height)
          emp (:,:) = sbcocn(:,:,10) - zdmp(:,:)
     $              + runoff(:,:) + erp(:,:) + empold
C
#else
C   ... Rigid-lid (emp=emps=E-P-R+Erp)
C
C     ... surface restoring term
          erp(:,:) = ( 1. - freezn(:,:) ) * zsrp
     $             * ( sbcocn(:,:,7) - sdta(:,:,1) )
     $             / ( sbcocn(:,:,7) + rsmall      )
C     ... freshwater flux
          emps(:,:) = sbcocn(:,:,10) + sbcocn(:,:,4)
     $              + runoff(:,:) + erp(:,:)
          emp (:,:) = emps(:,:)
C
C
C Sea ice fraction
          freeze(:,:) = sbcocn(:,:,6)
C ice albedo
          alb_ice(:,:) = sbcocn(:,:,8)
C ice temperature
          tn_ice(:,:) = sbcocn(:,:,9)
#endif
C
C
C Surface stress
C --------------
C
C ... update the stress beloww sea-ice area
          DO jj = 1, jpjm1
            DO ji = 1, jpim1
C   ... ice/ocean indicator at U- and V-points
              ztx = MAX( freezn(ji,jj), freezn(ji,jj+1) )
              zty = MAX( freezn(ji,jj), freezn(ji+1,jj) )
C   ... ice-ocean stress at U- and V-points
              ztaux = 0.5*( sbcocn(ji+1,jj,1) + sbcocn(ji+1,jj+1,1) )
              ztauy = 0.5*( sbcocn(ji,jj+1,2) + sbcocn(ji+1,jj+1,2) )
C   ... stress at the ocean surface
              taux(ji,jj) = (1.-ztx)*taux(ji,jj) + ztx*ztaux
              tauy(ji,jj) = (1.-zty)*tauy(ji,jj) + zty*ztauy
            END DO
          END DO
C ... boundary condition on the stress (taux,tauy)
          CALL lbc2( taux, 2, 0, 1, 1, 1, 1 )
          CALL lbc2( tauy, 3, 0, 1, 1, 1, 1 )
C
C
C Initialization
C
          sbcocn(:,:,6:9)=0.e0
      ENDIF 
#endif
#endif
C
C
      RETURN
      END
