CCC---------------------------------------------------------------------
CCC
CCC                      icelln.coupled.h
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC     CALL the Louvain la Neuve Sea Ice Model 
CCC     Coupled case
CC
CC   Modifications :
CC   --------------
CC    Original              : 2000-10 (O. Marti)
CC    Cerfacs Predicate Run : 2001-06 (S.Valcke-E.Maisonnave)
CC
C zciobc
C 
C  1: Net short wave (up+down) on open ocean
C  2: Net short wave (up+down) on sea ice
C  3: Net long wave  (up+down) on open ocean
C  4: Net long wave  (up+down) on sea ice
C      UNIT : W/m2
C  5: Water budget ( precip - evap )                      
C      UNIT : mm/day
C  6: Solid precipitation (snow)  (positive values)
C      UNIT : mm/day
C  7: Runoff (positive values) 
C      UNIT : mm/day
C  8: Derivative of sens+lat heat flux over sea ice
C      UNIT : W/m2/K
C  9: Wind stress over open ocean along i                 
C 10: Wind stress over sea ice along i                
C 11: Wind stress over open ocean along j                 
C 12: Wind stress over sea ice along j   
C      UNIT : N/m2             
C 13: Calving (positive values)
C      UNIT : mm/day
C
C sbocn
C  1: Wind stress under sea ice along i
C  2: Wind stress under sea ice along j
C      UNIT : Pa
C  3: Net long wave
C      UNIT : W/m2
C  4: Freshwater flux (concentration/dilution effect)
C         ( evap - precip + concentration - dilution )
C      UNIT : kg/m2/s
C  5: Net short wave
C      UNIT : W/m2
C  6: T surface (ORCA -> LIM) | Sea ice fraction (LIM -> ORCA)
C      UNIT : Kelvin          |  fraction [0-1]
C  7: S surface
C      UNIT : PSU
C  8: Surface velocity along i (ORCA -> LIM) | Surface albedo (LIM -> ORCA)
C  9: Surface velocity along j
C      UNIT : m/s
C 10: Freshwater flux (volume flux for free surface)
C      UNIT : kg/m2/s
c 11: Calving (negative value)
C      UNIT : kg/m2/s
C
CC----------------------------------------------------------------------
C
      IF ( MOD(kt-1,nexco) .EQ. 0 ) THEN 
C
C Initialize fields
C
          DO jj=2,jpj
            DO ji=2,jpi
C ...  8: Wind stress on open ocean along i              
              zciobc (ji,jj, 9) = FLOAT ( nfice-1) *
     $            0.5*(sciobc(ji-1,jj, 9)+sciobc(ji-1,jj-1, 9))
C ...  9: Wind stress on sea ice along i              
              zciobc (ji,jj,10) = FLOAT ( nfice-1) *
     $            0.5*(sciobc(ji-1,jj,10)+sciobc(ji-1,jj-1,10))
C ... 10: Wind stress on open ocean j               
              zciobc (ji,jj,11) = FLOAT ( nfice-1) *
     $            0.5*(sciobc(ji,jj-1,11)+sciobc(ji-1,jj-1,11))
C ... 11: Wind stress on sea ice along j               
              zciobc (ji,jj,12) = FLOAT ( nfice-1) *
     $            0.5*(sciobc(ji,jj-1,12)+sciobc(ji-1,jj-1,12))
            END DO  
          END DO 
          
          zciobc (:,:,1:8) = FLOAT ( nfice-1) * sciobc (:,:,1:8)
          zciobc (:,:,13) = FLOAT ( nfice-1) * sciobc (:,:,13)
C
      END IF       
C
C Cumulates fields
C
      sbcocn(:,:,6) = sbcocn(:,:,6) + tn(:,:,1) + rt0
      sbcocn(:,:,7) = sbcocn(:,:,7) + sn(:,:,1)
C
C vectors at F-point  
C
      DO jj=2,jpj
        DO ji=2,jpi
          sbcocn(ji,jj,8)=sbcocn(ji,jj,8)+0.5*(un(ji-1,jj,1)
     $        +un(ji-1,jj-1,1))
          sbcocn(ji,jj,9)=sbcocn(ji,jj,9)+0.5*(vn(ji,jj-1,1)
     $        +vn(ji-1,jj-1,1))
        END DO
      END DO
C
      zciobc (:,:,1:8) = zciobc (:,:,1:8) + sciobc (:,:,1:8)
      zciobc (:,:,13) = zciobc (:,:,13) + sciobc (:,:,13)
C
      DO jj=2,jpj
        DO ji=2,jpi
C ...  8: Wind stress on open ocean along i              
          zciobc (ji,jj, 9) = zciobc (ji,jj, 9)
     $        + 0.5*(sciobc(ji-1,jj, 9)+sciobc(ji-1,jj-1, 9))
C ...  9: Wind stress on sea ice along i              
          zciobc (ji,jj,10) = zciobc (ji,jj,10)
     $        + 0.5*(sciobc(ji-1,jj,10)+sciobc(ji-1,jj-1,10))
C ... 10: Wind stress on open ocean j               
          zciobc (ji,jj,11) = zciobc (ji,jj,11)
     $        + 0.5*(sciobc(ji,jj-1,11)+sciobc(ji-1,jj-1,11))
C ... 11: Wind stress on sea ice along j               
          zciobc (ji,jj,12) = zciobc (ji,jj,12)
     $        + 0.5*(sciobc(ji,jj-1,12)+sciobc(ji-1,jj-1,12))
        END DO  
      END DO 
C
      CALL lbcice (zciobc(:,:, 9), 4, 0, 1, 1 )
      CALL lbcice (zciobc(:,:,10), 4, 0, 1, 1 )
      CALL lbcice (zciobc(:,:,11), 4, 0, 1, 1 )
      CALL lbcice (zciobc(:,:,12), 4, 0, 1, 1 )
C      
      IF ( MOD(kt-1,nfice) .EQ. 0 ) THEN
          sbcocn (:,:,1:5) = 0.0e0
          sbcocn (:,:,6:9) = sbcocn(:,:,6:9)/FLOAT(nfice)
C
          zciobc = zciobc / FLOAT(nfice)
C
CEM  Runoff
CEM  Field not processed by ice model : 
CEM   unity conversion must be done here
CEM       mm/day -> kg/m2/sec
C
          runoff = zciobc(:,:,7)/rday
          WRITE (numout,*) 'Init calv ', zciobc(52,2,13)
C
C ... put DATA from ocean model to ice model
CC
C$$$          WRITE (numout,*) 'icelln : extremas tn_ice '
C$$$          WRITE (numout,*)
C$$$     $          minval(tn_ice(:,:),mask = tmask(:,:,1) .GE. 0.5),
C$$$     $          maxval(tn_ice(:,:),mask = tmask(:,:,1) .GE. 0.5)
C$$$          WRITE (numout,*) 'icelln : extremas zciobc '
C$$$          DO jj = 1, 12
C$$$            WRITE(numout,*) jj, 
C$$$     $          minval(zciobc(:,:,jj),mask = tmask(:,:,1) .GE. 0.5),
C$$$     $          maxval(zciobc(:,:,jj),mask = tmask(:,:,1) .GE. 0.5)
C$$$          END DO 
C$$$          WRITE (numout,*) 'icelln : extremas sbcocn '
C$$$          DO jj = 1, 10
C$$$            WRITE(numout,*) jj, 
C$$$     $          minval(sbcocn(:,:,jj),mask = tmask(:,:,1) .GE. 0.5),
C$$$     $          maxval(sbcocn(:,:,jj),mask = tmask(:,:,1) .GE. 0.5)
C$$$          END DO 
C
          CALL ocetoice(zciobc,sbcocn)
          IF ( nacc .EQ. 1 ) THEN 
              zdtsd2=0.5*rdtmin*nfice
          ELSE 
              zdtsd2=0.5*rdt*nfice
          ENDIF
C
C Ice model call
C
          CALL icemodel(raass,zdtsd2,nfice*rdttra(1))
C
C from ice to ocean model
C
          CALL icetooce(sbcocn)
C
          CALL lbcice  (sbcocn(:,:, 1), 4, 0, 1, 1 )
          CALL lbcice  (sbcocn(:,:, 2), 4, 0, 1, 1 )
          CALL lbc2    (sbcocn(:,:, 3), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:, 4), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:, 5), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:, 6), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:, 8), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:, 9), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:,10), 1, 1, 1, 1, 1, 1 )
          CALL lbc2    (sbcocn(:,:,11), 1, 1, 1, 1, 1, 1 )
C
C$$$          WRITE(numout,*) 'Extremas sbcocn apres glace ', kt
C$$$          DO ji = 1, 10
C$$$            WRITE(numout,*) ji, 
C$$$     $          MINVAL(sbcocn(:,:,ji),mask=(tmask(:,:,1)>0.5)),
C$$$     $          MAXVAL(sbcocn(:,:,ji),mask=(tmask(:,:,1)>0.5))
C$$$          END DO 
C
C sbcocn Sea ice oceanic variables  --> ocean model
C
C temperature and salt damping 
C$$$          ztrp = -40.0e0          
C$$$          zsrp  = ztrp * ro0cpr * rauw
C
          ztrp = 0.0e0
          zsrp = 0.0e0
C
C ... zero of the computer
C         rsmall
C
#if defined key_freesurf_cstvol && defined key_tradmp
C 
C ... vertical mean of damping trend (computed in tradmp.F)
          zstrdmp(:,:) = 0.e0
          DO jk = 1, jpk
            DO jj = 1, jpj
              DO ji = 1, jpi
                zstrdmp(ji,jj) = zstrdmp(ji,jj) +
     $              strdmp(ji,jj,jk)*fse3t(ji,jj,jk)*htr(ji,jj)
              END DO
            END DO
          END DO
#endif
C
C ... Sea ice fraction
          freeze (:,:) = sbcocn(:,:,6)
C ... Ice albedo
          alb_ice(:,:) = sbcocn(:,:,8)
C ... Ice temperature
          tn_ice (:,:) = sbcocn(:,:,9)
C ... Calving
          calv(:,:)= -sbcocn(:,:,11)
      WRITE (numout, *) 'Fin calv ', calv(52,2)
      call flush(numout)
c
          DO jj=1,jpj
            DO ji=1,jpi
C ... non solar heat flux (w/m2) + solar flux (W/m2)
              q(ji,jj) =sbcocn(ji,jj,3)+sbcocn(ji,jj,5)
              qt(ji,jj)=q(ji,jj)
C ... solar flux (W/m2)
              qsr(ji,jj) = sbcocn(ji,jj,5)
C ... water flux (en kg/m2/s)
              qrp(ji,jj) = 0.0e0
#if defined key_freesurf_cstvol
C
              zerp = 0.0e0
#  if defined key_tradmp
C ... volume flux associated to internal damping to climatology
              zdmp(ji,jj) = zstrdmp(ji,jj) * fse3t(ji,jj,1) * 1.e3
     $            / ( sbcocn(ji,jj,7) + rsmall )
#  else
              zdmp(ji,jj) = 0.0e0
#  endif
C ... volume flux associated to surface restoring term with a decrease
C     below sea-ice area
              erp (ji,jj) = 0.0e0
C ... total concentration/dilution effect (use on SSS)
              emps(ji,jj) = sbcocn(ji,jj,10) + sbcocn(ji,jj,4) 
     $                    - runoff(ji,jj) + erp(ji,jj)
     $                    - calv(ji,jj)
C ... total volume flux (use on sea-surface height)
              emp (ji,jj) = sbcocn(ji,jj,10) + zdmp(ji,jj)
     $                    - runoff(ji,jj) + erp(ji,jj)
     $                    - calv(ji,jj)
#else
c$$$              zerp = zsrp * ( sbcocn(ji,jj,7) - sdta(ji,jj,1) )
c$$$     $                    / ( sbcocn(ji,jj,7) + rsmall         )
              zerp = 0.0e0
C
              erp (ji,jj) = 0.0e0
              emps(ji,jj) = sbcocn(ji,jj,10) + sbcocn(ji,jj,4)
     $                    - runoff(ji,jj) + erp(ji,jj)
     $                    - calv(ji,jj)
              emp (ji,jj) = emps(ji,jj) 
#endif
              
            END DO
          END DO
C
C ... Wind stress
          DO jj = 1, jpj-1
            DO ji = 1, jpi-1
              ztx   = 0.5 * ( freeze(ji+1,jj  ) + freeze(ji+1,jj+1)   )
              ztaux = 0.5 * ( sbcocn(ji+1,jj,1) + sbcocn(ji+1,jj+1,1) )
              taux(ji,jj) = (1.0-ztx) * taux(ji,jj) + ztx * ztaux
C
              zty   = 0.5 * ( freeze(ji,jj+1  ) + freeze(ji+1,jj+1  ) )
              ztauy = 0.5 * ( sbcocn(ji,jj+1,2) + sbcocn(ji+1,jj+1,2) )
              tauy(ji,jj) = (1.0-zty) * tauy(ji,jj) + zty * ztauy
            END DO
          END DO
C
          CALL lbc2 (taux, 2, 1, 1, 1, 1, 1 )
          CALL lbc2 (tauy, 3, 1, 1, 1, 1, 1 )
C
C$$$          WRITE (numout,*) 'icelln : Extremas flux after ice model', kt
C$$$          WRITE (numout,*) 'q       : ', 
C$$$     $        MINVAL(  q    ,mask=(tmask(:,:,1)>0.5)),
C$$$     $        MAXVAL(  q    ,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'qt      : ', 
C$$$     $        MINVAL(  qt   ,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL(  qt   ,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'qsr     : ', 
C$$$     $        MINVAL( qsr   ,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( qsr   ,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'qrp     : ', 
C$$$     $        MINVAL( qrp   ,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( qrp   ,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'emp     : ', 
C$$$     $        MINVAL( emp   ,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( emp   ,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'erp     : ',
C$$$     $        MINVAL( erp   ,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( erp   ,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'freeze  : ',
C$$$     $        MINVAL( freeze,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( freeze,mask=(tmask(:,:,1)>0.5))
C$$$          WRITE (numout,*) 'alb_ice : ',
C$$$     $        MINVAL(alb_ice,mask=(tmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL(alb_ice,mask=(tmask(:,:,1)>0.5))
C$$$           WRITE (numout,*) 'taux   : ', 
C$$$     $        MINVAL( taux  ,mask=(umask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( taux  ,mask=(umask(:,:,1)>0.5))
C$$$           WRITE (numout,*) 'tauy   : ', 
C$$$     $        MINVAL( tauy  ,mask=(vmask(:,:,1)>0.5)), 
C$$$     $        MAXVAL( tauy  ,mask=(vmask(:,:,1)>0.5))
C
C Initialization
C
          sbcocn (:,:,6:9) = 0.0e0
C
          zciobc = 0.0e0
C
      ENDIF 
C
