CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/inicmo.F,v 1.1.1.1.6.3 2002/02/04 13:45:23 maisonna Exp $
CDIR$ LIST
      SUBROUTINE inicmo( kastp, kexch, kstep )
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE inicmo
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC             *****************
CCC             * OASIS routine *
CCC             * ------------- *
CCC             *****************
CCC
CCC   Initialize coupled mode communication for ocean
CCC   exchange process identifiers and timestep information
CCC   between AGCM, OGCM and COUPLER.
CCC
CC   Method :
CC   -------
CC    3 types :
CC    a) Use named pipes(FIFO) to exchange process identifiers
CC      between the 3 programs
CC    b) USE a messag passing method with PVM language (CLIM)
CC    c) USE SVIPC method
CC
CC   Input :
CC   ------
CC      kastp : total number of timesteps in oceanic model
CC      kexch : frequency of exchange for the fluxes (in time steps)
CC      kstep : timestep value (in seconds)
CC
CC  Output :  none
CC  -------
CC
CC      explicit arguments:
CC      ------------------
CC        none
CC
CC      implicit arguments:
CC      ------------------
CC        common
CC              /CPIDOC/npiat     : agcm process identifier
CC                      npicp     : coupler process identifier
CC                      npioc     : ogcm process identifier
CC
CC  External :
CC  ---------
CC     getpid
CC     assign
CC     mknod
CC
CC  Reference :
CC  ----------
CC      see Epicoa 0803 (1992)
CC
CC   Modifications :
CC   --------------
CC       original  : 92-09 (Laurent Terray)
CC       modified  : 96-07 (Laurent Terray) : OASIS version 2
CC       modified  : 96-11 (Eric Guilyardi) : run-off + Taux,Tauy x2
CC       modified  : 98-04 (M.A Foujols, S. Valcke, M. Imbard) OASIS2.2
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER kastp, kexch, kstep
#if defined key_coupled
      INTEGER iparal(3)
      INTEGER ifcpl, idt, info, imxtag, istep
c
      CHARACTER*9 clpoolnam 
      INTEGER ipoolhandle, ipoolsize, index, jf
      CHARACTER*3 cljobnam      ! experiment name
      INTEGER ierror
c     -----------------------------------------------------------
      INTEGER imess(4), imesso(4)
      INTEGER getpid, mknod     ! system functions
c     
      WRITE(numout,*) ' '
      WRITE(numout,*) ' '
      WRITE(numout,*) ' ROUTINE INICMO'
      WRITE(numout,*) ' **************'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' '
      CALL flush(numout)
C
C Define imess (infos exchanged with coupler)
      imess(1)=kastp
      imess(2)=kexch
      imess(3)=kstep
      imess(4)=getpid()
C
C II SVIPC
C---------
C
C
      IF (cchan.eq.'SIPC') THEN
c
c debug for more information
c
c          CALL SVIPC_debug(1)
c
c  
c     1.1-Define the experiment name :
c
          cljobnam = 'PR1'      ! as $JOBNAM in namcouple
c  
c
c         3-Attach to shared memory pool used to exchange initial infos 
c
          info = 0
          CALL SIPC_Init_Model (cljobnam, cplmodnam, 1, info)
          IF (info .NE. 0) THEN 
             WRITE (numout,*)'   '
             WRITE (numout,*)'WARNING: Problem with attachement to',info 
             WRITE (numout,*)'         initial memory pool(s) in ocean'
             WRITE (numout,*)'   '
             CALL ABORT('STOP in ocean')
          ENDIF
c
c         4-Attach to pools used to exchange fields from ocean to coupler
c
 	  DO jf = 1, nfldo2c
C
c           Pool name:
            clpoolnam = 'P'//cpl_writ(jf)
C
            CALL SIPC_Attach(clpoolnam, ipoolhandle)
c     
c           Resulting pool handle:
            mpoolwrit(jf) = ipoolhandle  
C
          END DO 
C
c         5-Attach to pools used to exchange fields from coupler to ocean
c
          DO jf = 1, nflxc2o
c
c           Pool name:
            clpoolnam = 'P'//cpl_readflx(jf)
c
            CALL SIPC_Attach(clpoolnam, ipoolhandle)
c
c           Resulting pool handle:
            mpoolread(jf) = ipoolhandle  
c
          END DO  
          DO jf = 1, ntauc2o
c
c           Pool name:
            clpoolnam = 'P'//cpl_readtau(jf)
c
            CALL SIPC_Attach(clpoolnam, ipoolhandle)
c
c           Resulting pool handle:
            mpoolread(jf+nflxc2o) = ipoolhandle  
c
          END DO 
c
c         6-Exchange of initial infos
c
c         Write data array isend to pool READ by Oasis
c
          info = 0
          ipoolsize = 4*jpbyteint
          WRITE (numout,*) 'imess '
          WRITE (numout,*) 'imess(1)', imess(1)
          WRITE (numout,*) 'imess(2)', imess(2)
          WRITE (numout,*) 'imess(3)', imess(3)
          WRITE (numout,*) 'imess(4)', imess(4)
          CALL flush(numout)
          CALL SVIPC_write(mpoolinitr, imess, ipoolsize, info)
C
C         Find error if any
C
          IF (info .LT. 0) THEN
              WRITE (numout,*) '   '
              WRITE (numout,*) 'Problem in ocean in writing initial' 
              WRITE (numout,*) 'infos to the shared memory segment(s)'
              WRITE (numout,*) '   '
          ELSE
              WRITE (numout,*) '   '
              WRITE (numout,*) 'Initial infos written in ocean'            
              WRITE (numout,*) 'to the shared memory segment(s)'
              WRITE (numout,*) '   '
          ENDIF
C
C         Read data array irecv from pool written by Oasis
C
          info = 0
          ipoolsize = 4*jpbyteint
          CALL svipc_read(mpoolinitw, imesso, ipoolsize, info)
C
C*        Find error if any
C
          IF (info .LT. 0) THEN
              WRITE (numout,*) '   '
              WRITE (numout,*) 'Problem in ocean in reading initial' 
              WRITE (numout,*) 'infos from the shared memory segment(s)'
              WRITE (numout,*) '   '
          ELSE
              WRITE (numout,*) '   '
              WRITE (numout,*) 'Initial infos read by ocean'                
              WRITE (numout,*) 'from the shared memory segment(s)'
              WRITE (numout,*) '   '
              WRITE(*,*) ' ntime, niter, nstep, Oasis pid:'
              WRITE(*,*) imesso(1), imesso(2), imesso(3), imesso(4) 
          ENDIF
C
C         Detach from shared memory segment(s)
C
          info = 0
          CALL SVIPC_close(mpoolinitw, 0, info)
C
C         Find error if any
C
          IF (info .LT. 0) THEN
              WRITE (numout,*) 
     $          'Problem in detaching from shared memory segment(s)'
              WRITE (numout,*)
     $          'used by ocean to read initial infos' 
          ENDIF
c
C III CLIM
C --------
C
      ELSE IF (cchan.eq.'CLIM') THEN
c
c     Define the number of processors involved in the coupling for
c     Oasis (=1) and each model (as last two INTEGER on $CHATYPE line
c     in the namcouple); they will be stored in a COMMON in mpiclim.h
c     (used for CLIM/MPI2 only)
      mpi_nproc(0)=1
      mpi_nproc(1)=1
      mpi_nproc(2)=1 
c         Define the number of processors used by each model as in
c         $CHATYPE line of namcouple (used for CLIM/MPI2 only)
          mpi_totproc(1)=1
          mpi_totproc(2)=1
c
c         Define names of each model as in $NBMODEL line of namcouple
c         (used for CLIM/MPI2 only)
          cmpi_modnam(1)='lmdz.x'
          cmpi_modnam(2)=cplmodnam
c  
c     1.1-Define the experiment name :
c
          cljobnam = 'CLI'      ! as $JOBNAM in namcouple

          OPEN ( UNIT = 7, FILE = 'trace', STATUS = 'unknown',
     $          FORM = 'formatted')
          CALL clim_init ( cljobnam, cplmodnam, 3, 7,
     *                 kastp, kexch, kstep,
     *                 5, 3600, 3600, info )
c
          IF (info.ne.clim_ok) THEN
              WRITE ( numout, *) ' inicmo : pb init clim '
              WRITE ( numout, *) ' error code is = ', info
              CALL abort('STOP in inicmo')
            ELSE
              WRITE(numout,*) 'inicmo : init clim ok '
          ENDIF
c
          iparal ( clim_strategy ) = clim_serial
          iparal ( clim_length   ) = jpiglo*jpjglo
          iparal ( clim_offset   ) = 0
c
c loop to define messages (CPL=atmos to ocean)
c
          DO jf=1, nflxc2o
            CALL CLIM_Define (cpl_readflx(jf), clim_in , clim_double,
     $          iparal, info )  
          END DO 
          DO jf=1, ntauc2o
            CALL CLIM_Define (cpl_readtau(jf), clim_in , clim_double,
     $          iparal, info )  
          END DO              
c
c loop to define messages (ocean to CPL=atmos)
c
          DO jf=1, nfldo2c
            CALL CLIM_Define (cpl_writ(jf), clim_out , clim_double,
     $          iparal, info )   
          END DO 
c
          WRITE(numout,*) 'inicmo : clim_define ok '
          CALL CLIM_Start ( imxtag, info )
          IF (info.ne.clim_ok) THEN
              WRITE ( numout, *) 'inicmo : pb start clim '
              WRITE ( numout, *) ' error code is = ', info
              CALL abort('stop in inicmo')
            ELSE
              WRITE ( numout, *)  'inicmo : start clim ok '
          ENDIF
c
          CALL CLIM_Stepi (cploasis, istep, ifcpl, idt, info)
          IF (info .NE. clim_ok) THEN
              WRITE ( UNIT = numout, FMT = *)
     $            ' warning : problem in getting step info ',
     $            'from oasis '
              WRITE (UNIT = numout, FMT = *)
     $            ' =======   error code number = ', info
            ELSE
              WRITE (UNIT = numout, FMT = *)
     $            ' got step information from oasis '
          ENDIF
          WRITE ( numout, *) ' number of tstep in oasis ', istep
          WRITE ( numout, *) ' exchange frequency in oasis ', ifcpl
          WRITE ( numout, *) ' length of tstep in oasis ', idt
      ENDIF
C
C 5. End of program
C -----------------
#endif
C
      RETURN
      END
