CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/inidtr.F,v 1.1.1.1.6.3 2002/02/04 13:45:24 maisonna Exp $
      SUBROUTINE inidtr
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE inidtr
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC     Initialization of the dynamics and tracers.
CCC
CC   Method :
CC   -------
CC
CC   Input :
CC   ------
CC
CC   Output :
CC   -------
CC      argument                : no
CC            /combef/          : previous fields (before)
CC            /comnow/          : present fields (now)
CC            /comaft/          : next fields (after)
CC            /comtra/          : tracers trends
CC            /comtrd/          : dynamics trends
CC            /combsf/          : barotropic stream function
CC
CC   External :  dtrlec, dtrtem, dtatem, dtrsal, dtasal,
CC   ---------   eos, bn2, wzv
CC
CC   Modifications:
CC   --------------
CC      original  : 91-03 ()
CC      additions : 91-11 (G. Madec)
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER ji, jj, jk, jn, jtask
#if defined key_freesurf_cstvol && ! defined key_ice_lln
      CHARACTER*32 clname
      LOGICAL clbon
#endif
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (1997)
CCC---------------------------------------------------------------------
C
C
C 0. Initialization to zero
C -------------------------
C
C ... Non penetrative convective scheme statistics
      nnpcc = 0
      nnpci = 0
C
C 0.1 common/combef/
C
      DO jk = 1, jpk
        DO jj = 1, jpj
          DO ji = 1, jpi
            ub   (ji,jj,jk) = 0.e0
            vb   (ji,jj,jk) = 0.e0
            tb   (ji,jj,jk) = 0.e0
            sb   (ji,jj,jk) = 0.e0
            rotb (ji,jj,jk) = 0.e0
            hdivb(ji,jj,jk) = 0.e0
          END DO  
        END DO  
      END DO  
C
C 0.2 common/comnow/
C
      DO jk = 1, jpk
        DO jj = 1, jpj
          DO ji = 1, jpi
            un   (ji,jj,jk) = 0.e0
            vn   (ji,jj,jk) = 0.e0
            wn   (ji,jj,jk) = 0.e0
            rotn (ji,jj,jk) = 0.e0
            hdivn(ji,jj,jk) = 0.e0
            tn   (ji,jj,jk) = 0.e0
            sn   (ji,jj,jk) = 0.e0
            rdn  (ji,jj,jk) = 0.e0
            rhopn(ji,jj,jk) = 0.e0
            bn2n (ji,jj,jk) = 0.e0
          END DO
        END DO
      END DO
C
C 0.3 common/comaft/
C
      DO jk = 1, jpk
        DO jj = 1, jpj
          DO ji = 1, jpi
            ua(ji,jj,jk) = 0.e0
            va(ji,jj,jk) = 0.e0
            ta(ji,jj,jk) = 0.e0
            sa(ji,jj,jk) = 0.e0
          END DO
        END DO
      END DO
C
C common/comspg/
C
      DO jj = 1, jpj
        DO ji = 1, jpi
          spgu(ji,jj) = 0.e0
          spgv(ji,jj) = 0.e0
        END DO
      END DO
C
C 0.4 common/comtrd/
C
#if defined key_diatrddyn
C
      DO jn = 1, 9
        DO jk = 1, jpk
          DO jj = 1, jpj
            DO ji = 1, jpi
              utrd(ji,jj,jk,jn) = 0.e0
              vtrd(ji,jj,jk,jn) = 0.e0
            END DO
          END DO
        END DO
      END DO
      DO jn = 1, 2
        DO jj = 1, jpj
          DO ji = 1, jpi
            tautrd(ji,jj,jn) = 0.e0
          END DO
        END DO
      END DO
C
#  else
C
C    No dynamic trend diagnostics
C
#endif
#if defined key_diaspr
C
       DO jj = 1, jpj
         DO ji = 1, jpi
           gps  (ji,jj) = 0.e0
           gpsuu(ji,jj) = 0.e0
           gpsvv(ji,jj) = 0.e0
         END DO
       END DO
C
#  else
C
C    No surface pressure diagnostics
C
#endif
C
C 0.5 common/comtra/
C
#if defined key_diatrdtra || defined key_diatrdmld
      DO jn = 1, 7
        DO jk = 1, jpk
          DO jj = 1, jpj
            DO ji = 1, jpi
              ttrd(ji,jj,jk,jn) = 0.e0
            END DO
          END DO
        END DO
      END DO
C
      DO jn = 1, 6
        DO jk = 1, jpk
          DO jj = 1, jpj
            DO ji = 1, jpi
              strd(ji,jj,jk,jn) = 0.e0
            END DO
          END DO
        END DO
      END DO
C
      DO jn = 1, 2
        DO jj = 1, jpj
          DO ji = 1, jpi
            flxtrd(ji,jj,jn) = 0.e0
          END DO
        END DO
      END DO
C
      DO jn = 1, jptrdh
        DO jk = 1, jpk
          DO jj = 1, jpj
            DO ji = 1, jpi
              ttrdh(ji,jj,jk,jn) = 0.e0
              strdh(ji,jj,jk,jn) = 0.e0
            END DO
          END DO
        END DO
      END DO
C
#  else
C
C    No tracers trend diagnostics
C
#endif
#if defined key_diatrdmld && defined key_trahdfeiv
      DO jk = 1, jpk
        DO jj = 1, jpj
          DO ji = 1, jpi
            wgn(ji,jj,jk) = 0.e0
          END DO
        END DO
      END DO
#endif
#if defined key_ice_igloo && ! defined key_diatrdtra
      DO jn = 1, 2
        DO jj = 1, jpj
          DO ji = 1, jpi
            flxtrd(ji,jj,jn) = 0.e0
          END DO
        END DO
      END DO
#endif
C
C 0.6 diawri array
C
      DO jj = 1, jpj
        DO ji = 1, jpi
          hmld(ji,jj) = 0.e0
          hmlp(ji,jj) = 0.e0
          hmln(ji,jj) = 0.e0
          hth (ji,jj) = 0.e0
          hd20(ji,jj) = 0.e0
        END DO
      END DO
#if defined key_mpp && ! defined key_diainstant
      DO jk = 1, jpk
        DO jj = 1, jpj
          DO ji = 1, jpi
            fsel(ji,jj,jk) = 0.e0
          END DO
        END DO
      END DO
#endif
      DO jj = 1, jpj
        DO ji = 1, jpi
          taux  (ji,jj) = 0.e0
          tauy  (ji,jj) = 0.e0
          tauxg (ji,jj) = 0.e0
          tauyg (ji,jj) = 0.e0
          q     (ji,jj) = 0.e0
          qt    (ji,jj) = 0.e0
          qsr   (ji,jj) = 0.e0
          qrp   (ji,jj) = 0.e0
          emp   (ji,jj) = 0.e0
          erp   (ji,jj) = 0.e0
          runoff(ji,jj) = 0.e0
          freeze(ji,jj) = 0.e0
        END DO
      END DO
C
C 0.8 common/comdhd/
C
#if defined key_trahdfiso || defined key_dynhdfiso || defined key_trahdfgeop || defined key_dynhdfgeop 
      DO jk=1,jpk
        DO jj=1,jpj
          DO ji=1,jpi
            uslp (ji,jj,jk) = 0.e0
            vslp (ji,jj,jk) = 0.e0
            wslpi(ji,jj,jk) = 0.e0
            wslpj(ji,jj,jk) = 0.e0
          END DO
        END DO
      END DO
#endif
C
C 0.9 common/comeiv/
C
#if defined key_diaeiv && defined key_trahdfeiv
C
      DO jk=1,jpk
        DO jj=1,jpj
          DO ji=1,jpi
            ugm (ji,jj,jk) = 0.e0
            vgm (ji,jj,jk) = 0.e0
            wgm (ji,jj,jk) = 0.e0
          END DO
        END DO
      END DO
#endif
C
#if defined key_ice_lln
      tn_ice  (:,:) = (273.15-1.8 ) * tmask(:,:,1)
      alb_ice (:,:) = 0.8 * tmask(:,:,1)
#endif
C
C ... Read the corrective factor on precipitations (empold)
#if defined key_freesurf_cstvol && ! defined key_coupled
      clname = 'EMPave_old.dat'
      INQUIRE(FILE=clname,EXIST=clbon)
      IF (clbon) THEN 
          OPEN(111,FILE=clname)
          READ(111,9005)empold
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*)' inidtr : global EMP coeff = ', empold
          IF(lwp)WRITE(numout,*)
 9005     FORMAT(24X,ES24.16)
          CLOSE(111)
      ELSE
          IF(lwp) THEN
              WRITE(numout,*)
              WRITE(numout,*)' inidtr : unable to read the file', clname
              WRITE(numout,*)
          ENDIF
          STOP 'inidtr'
      ENDIF
#endif
C          
C
      IF(lrstar) THEN
C
C 2. Restart from numrst
C ----------------------
C
C ... Read the restart file
          CALL dtrlec
C
C ... Set time-step indicator at nit000 (leap-frog)
          neuler = 1
C
        ELSE
C
C 3. Start from rest
C ------------------
C
#if defined key_freesurf_cstvol
C
C ... free surface formulation
          DO jj = 1, jpj
            DO ji = 1, jpi
              etab(ji,jj) = 0.e0
              etan(ji,jj) = 0.e0
            END DO
          END DO
# else
C
C ... rigid-lid formulation
          DO jj = 1, jpj
            DO ji = 1, jpi
              bsfb(ji,jj) = 0.e0
              bsfn(ji,jj) = 0.e0
              bsfd(ji,jj) = 0.e0
            END DO
          END DO
#endif
C
C 3.1 Initial temperature and salinity fields
C
#if defined key_temdta
          DO jk = 1, jpk
            DO jj = 1, jpj
              DO ji = 1, jpi
                tb(ji,jj,jk) = tdta(ji,jj,jk)
                tn(ji,jj,jk) = tdta(ji,jj,jk)
              END DO
            END DO
          END DO
#  else
C         no temperature data
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*)' Temperature initialization using an',
     $        ' analytic profile'
          CALL dtrtem
#endif
C
#if defined key_saldta
          DO jk = 1, jpk
            DO jj = 1, jpj
              DO ji = 1, jpi
                sb(ji,jj,jk) = sdta(ji,jj,jk)
                sn(ji,jj,jk) = sdta(ji,jj,jk)
              END DO
            END DO
          END DO
#  else
C No salinity data
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*)' Salinity initialisation '
          CALL dtrsal
#endif
C
C 3.3 Set time-step indicator at nit000 (euler forward)
C
          neuler = 0
C
#if defined key_temdta && defined key_ice_igloo
C
C 3.4 Check that T >=freezing point
C
          DO jk = 1, jpk
            DO jj = 1, jpj
              DO ji = 1, jpi
                tn(ji,jj,jk)=max(tdta(ji,jj,jk),fsfzpt(sn(ji,jj,jk),0.))
     $                      *tmask(ji,jj,jk)
                tb(ji,jj,jk)=tn(ji,jj,jk)
              END DO
            END DO
          END DO
#endif
#if defined key_ice_lln
          DO jn = 1, 10
            DO jj = 1, jpj
              DO ji = 1, jpi
                sbcocn(ji,jj,jn) = 0.
              END DO
            END DO
          END DO      
            DO jj = 1, jpj
              DO ji = 1, jpi
                sbcocn(ji,jj,6) = sbcocn(ji,jj,6)
     $                          + ( nfice-1 )*( tn(ji,jj,1)+rt0 )
                sbcocn(ji,jj,7) = sbcocn(ji,jj,7)
     $                          + ( nfice-1 )*  sn(ji,jj,1)
              END DO
            END DO    
#if defined key_coupled
          DO jj = 1, jpj
            DO ji = 1, jpi
              sstmoy(ji,jj,1)= tn(ji,jj,1)+rt0
              sstmoy(ji,jj,2)= tn(ji,jj,1)+rt0
              sstmoy(ji,jj,3)= tn(ji,jj,1)+rt0
              END DO
            END DO    
#endif
#endif
      ENDIF
C
#if defined key_flx
      ndayflx = 0
      nyearflx = 0
#endif
#if defined key_tau
      ndaytau = 0
      nyeartau = 0
#endif
C
C
C 4. diagnostic fields at nit000
C -----------------------------
C
C ... In situ density
C
#if defined key_hpgimplicit
      ta(:,:,:)=2.*tn(:,:,:)-tb(:,:,:)
      sa(:,:,:)=2.*sn(:,:,:)-sb(:,:,:)
#endif
      DO jtask = 1, ncpu
        CALL eos( jtask, nit000 )
      END DO
#if defined key_hpgimplicit
      ta(:,:,:)=0.0
      sa(:,:,:)=0.0
#endif
C
C ... Brunt-Vaisala frequency
      DO jtask = 1, ncpu
        CALL bn2( jtask, nit000 )
      END DO
C
C ... Horizontal velocity : start from geostrophy (eel config)
#if (defined key_eel2 || defined key_eel6) && defined key_islands
      CALL dtruvg
#endif
C
C ... Vertical velocity
      DO jtask = 1, ncpu
        CALL wzv( jtask, nit000 )
      END DO
C
C
      RETURN
      END
