CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/parlec.F,v 1.1.1.1.6.3 2002/02/04 13:45:30 maisonna Exp $
CDIR$ LIST
      SUBROUTINE parlec
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE parlec
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC     Read and print options for the run (namelist)
CCC
CC   Method :                   : no
CC   -------
CC
CC   Input : 
CC   ------
CC      the namelist file ( unit numnam ) :
CC            &namdom           : domain parameters, masks, bathymetry
CC            &namhdf           : horizontal diffusion
CC            &namzdf           : vertical diffusion
CC            &namric           : richardson number dependent vertical
CC                                diffusion
CC            &namtke           : turbulent eddy kinetic dependent
CC                                vertical diffusion
CC	      &namddm		: double diffusive mixing
CC	      &nammbc		: lateral and bottom momentum boundary
CC				  conditions
CC            &namqsr           : penetrative solar radiation
CC            &namtdp           : tracer damping
CC            &namdia           : diagnostic
CC            &nameos           : ocean physical parameters
CC            &namrun           : parameters for the control
CC            &namtsk           : multitasking
CC            &namcpl           : coupled mode
CC            &namsol           : elliptic solver/islands/free surface
CC            &namobc           : open boundaries
CC
CC   Output :
CC   -------
CC      common
CC            /comdom/          : domain parameters
CC                                and scale factors
CC            /comcoh/          : horizontal coordinates and factors
CC            /comask/          : masks, bathymetry
CC            /comsol/          : elliptic solver
CC            /comisl/          : island
CC            /comfsf/          : free surface formulation
CC            /comhdd/          : lateral viscosity
CC            /comhdt/          : lateral diffusivity
CC            /comric/          : richardson number dependent vertical
CC                                diffusion
CC            /comtke/          : turbulent eddy kinetic dependent
CC                                vertical diffusion
CC            /comtau/          : surface wind stress
CC            /comflx/          : surface heat flux and evaporation
CC            /comqsr/          : penetrative solar radiation
CC            /comtda/          : temperature data
CC            /comsda/          : salinity data
CC            /comtdp/          : temperature and salinity damping
CC            /comtra/          : tracers trends
CC            /comtrd/          : dynamics trends
CC            /comeos		: ocean physical parameters
CC            /comstp/          : time step
CC            /comrst/          : restart parameter
CC            /comctl/          : parameters for the control
CC            /comwri/          : parameters for output 
CC            /comphy/          : parameters for physical process
CC            /comtsk/          : multitasking
CC            /comtst/          : timestep info for coupler
CC
CC   Modifications :
CC   --------------
CC      original : 90-10 (C. Levy - G. Madec)
CC      addition : 91-11 (G. Madec)
CC               : 91-12 (M. Imbard)
CC               : 92-06 (M. Imbard) ntrd
CC               : 99-09 (E. Guilyardi) nctls
CC               : 97-12 (C. Message- JM Molines) use rwrite
CC                        close numnam at the END
CC               : 00-08 (G. Madec) double diffusive mixing
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER jf
      INTEGER ilu, iused(1,100)
      INTEGER ilseq
#if defined key_eastobc || defined key_westobc || defined key_northobc || defined key_southobc
      REAL zbsic1, zbsic2, zbsic3
#endif
C
      CHARACTER*21 clold, clfor, clseq
      CHARACTER*32 clname
C
      NAMELIST/namrun/ no, cexper, lrstar, nrstdt, nit000, nitend
     $    , ndate0, nbisex, nstock, nprint, nwrite, ncpu, nrunoff
      NAMELIST/namdom/ ntopo, ngrid, nmsh, nizoom, njzoom, nizarc
     $    , njzarc, nacc, atfp, rdt, rdtmin, rdtmax, rdth, nfice
     $    , nclosea
      NAMELIST/namsol/ nsolv, nmax, eps, sor, epsisl, nmisl, rnu
      NAMELIST/namhdf/ ahm0, ahmb0, aht0, ahtb0, aeiv0
      NAMELIST/namzdf/ avm0, avt0, navmt, avevd, nnpc1, nnpc2
     $    , ntrbbl, atrbbl
      NAMELIST/namric/ avmri, alp, nric
      NAMELIST/namtke/ ediff, ediss, ebb, efave, emin, emin0, nitke
     $    , nmxl, npdl
      NAMELIST/namddm/ avts, hsbfr
      NAMELIST/nammbc/ shlat, nbotfr, bfri1, bfri2, bfeb2
      NAMELIST/namqsr/ rabs, xsi1, xsi2
      NAMELIST/namtdp/ ndmp, ndmpf, nmldmp, sdmp, bdmp, hdmp
      NAMELIST/nameos/ neos, rau0, ralpha, rbeta, rcp
      NAMELIST/namdia/ ntrd, nfznl, ngap, nprg, nctls
      NAMELIST/namspr/nmaxp,epsp,niterp
#if defined key_coupled
      NAMELIST/namcpl/ nexco, cchan, nmodcpl, cplmodnam, cploasis
     $    , nfldo2c, nflxc2o, ntauc2o, cpl_f_readflx, cpl_f_readtau
     $    , cpl_f_writ, cpl_readflx, cpl_readtau, cpl_writ
#endif
#if defined key_eastobc || defined key_westobc || defined key_northobc || defined key_southobc
      NAMELIST/namobc/ nieob, niwob, njnob, njsob,
     $                 rdpein, rdpwin, rdpnin, rdpsin,
     $                 rdpeob, rdpwob, rdpnob, rdpsob,
     $                 zbsic1, zbsic2, zbsic3
      REAL bsfic0
      common /bsfvar/bsfic0(1) 
#endif
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8.2, LODYC-IPSL (2001)
CCC---------------------------------------------------------------------
C
C
C 0. Initializations
C ------------------
C
C ... Open specifier
      clold = 'OLD'
      clfor = 'FORMATTED'
      clseq = 'SEQUENTIAL'
C
C ... Sequential value
      ilseq = 1
      ilu = 0
      DO jf = 1, 100
        iused(1,jf) = 0
      END DO
C
      IF(lwp) THEN
          WRITE(numout,*) ' '
          WRITE(numout,*) ' '
          WRITE(numout,*) ' routine parlec'
          WRITE(numout,*) ' **************'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' initialization of run'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' '
          WRITE(numout,*) ' namelist'
          WRITE(numout,*) ' ********'
          WRITE(numout,*) ' '
      ENDIF
C
      numnam = 4
      clname = 'namelist'
      CALL ctlopn( numnam, clname, clold, clfor, clseq,
     $                  ilseq, ilu, iused, numout, lwp, 1)
C
C
C 1. Read namlist files
C ---------------------
C
C
C ... Namelist namrun : parameters of the run
C
      no    =  0
      cexper=  "ex0"
      lrstar = .FALSE.
      nrstdt = 0
      nit000=  1
      nitend=  10
      ndate0=  961115
      nbisex=  0
      nprint= 0
      nstock= 10
      nwrite= 10
      ncpu = 4
      nrunoff = 0
C
      READ  ( numnam, namrun )
C
      IF(lwp) THEN
      WRITE(numout,*) 'namrun'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' job number                     no     = ',no
      WRITE(numout,*) ' vairmer name for output        cexper = ',cexper
      WRITE(numout,*) ' restart logical                lrstar = ',lrstar
      WRITE(numout,*) ' control of time step           nrstdt = ',nrstdt
      WRITE(numout,*) ' number of the first time step  nit000 = ',nit000
      WRITE(numout,*) ' number of the last time step   nitend = ',nitend
      WRITE(numout,*) ' initial calendar date aammjj   ndate0 = ',ndate0
      WRITE(numout,*) ' leap year calendar (0/1)       nbisex = ',nbisex
      WRITE(numout,*) ' level of print                 nprint = ',nprint
      WRITE(numout,*) ' frequency of restart file      nstock = ',nstock
      WRITE(numout,*) ' frequency of output file       nwrite = ',nwrite
      WRITE(numout,*) ' number of cpu                  ncpu   = ',ncpu
      WRITE(numout,*) ' runoff option                 nrunoff = '
     $    ,nrunoff
      WRITE(numout,*) ' '
      ENDIF
C
C     year=raajj*days day=rjjhh*hours hour=rhhmm*minutes etc ...
C
      IF (nbisex .eq. 1) THEN 
          raajj = 365.25
          raass = raajj * rjjss
          rmoss = raass/raamo
      ELSE IF  (nbisex .eq. 0) THEN
          raajj = 365.
          raass = raajj * rjjss
          rmoss = raass/raamo
      ELSE 
          raajj = nbisex*raamo
          raass = raajj *rjjss
          rmoss = nbisex*rjjss
      ENDIF 
      IF(lwp) THEN
      WRITE(numout,*) ' '
      WRITE(numout,*) ' nb of days per year      raajj = ',raajj,' days'
      WRITE(numout,*) ' nb of seconds per year   raass = ', raass, ' s'
      WRITE(numout,*) ' nb of seconds per month  rmoss = ', rmoss, ' s'
      ENDIF
C
C ... Namelist namdom : space/time domain (bathymetry, mesh, timestep)
C
      ntopo  = 0
      ngrid  = 0
      nmsh   = 0
      nizoom =  1
      njzoom =  1
      nizarc =  21
      njzarc =  97
C
      nacc   = 0
      atfp   = 0.1
      rdt    = 3600.
      rdtmin = 3600.
      rdtmax = 3600.
      rdth   = 800.
      nfice  = 3
      nclosea= 0
C
      READ  ( numnam, namdom )
C
      IF(lwp) THEN
      WRITE(numout,*) 'namdom'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' flag read/compute bathymetry   ntopo  = ',ntopo
      WRITE(numout,*) ' flag read/compute coordinates  ngrid  = ',ngrid
      WRITE(numout,*) ' flag write coordinates/meshes  nmsh   = ',nmsh 
      WRITE(numout,*) ' index i domain left bottom   nizoom   = ',nizoom
      WRITE(numout,*) ' index j domain left bottom   njzoom   = ',njzoom
      WRITE(numout,*) ' '
      WRITE(numout,*) ' acceleration of converge       nacc   = ',nacc
      WRITE(numout,*) ' asselin time filter parameter  atfp   = ',atfp
      WRITE(numout,*) ' time step                      rdt    = ',rdt
      WRITE(numout,*) ' minimum time step on tracers   rdtmin = ',rdtmin
      WRITE(numout,*) ' maximum time step on tracers   rdtmax = ',rdtmax
      WRITE(numout,*) ' depth variation tracer step    rdth   = ',rdth
#if defined key_ice_lln
      WRITE(numout,*) ' coupling frequency OPA ICELLN  nfice  = ',nfice
#endif
      WRITE(numout,*) ' flag closed sea or not         nclosea=',nclosea
      WRITE(numout,*) ' '

      ENDIF
#if defined key_arctic
      nizoom = nizarc
      njzoom = njzarc
#endif
C
C ... Namelist namhdf : horizontal diffusion
C
      ahm0   = 40000.
      ahmb0  = 0.
      aht0   = 2000.
      ahtb0  = 0.
      aeiv0  = 2000.
C
      READ  ( numnam, namhdf )
C
      IF(lwp) THEN
      WRITE(numout,*) 'namhdf'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' horizontal eddy viscosity      ahm0   = ',ahm0
      WRITE(numout,*) ' background viscosity           ahmb0  = ',ahmb0
      WRITE(numout,*) ' horizontal eddy diffusivity    aht0   = ',aht0
      WRITE(numout,*) ' background diffusivity         ahtb0  = ',ahtb0
      WRITE(numout,*) ' eddy induced velocity coef.    aeiv0  = ',aeiv0
      WRITE(numout,*) ' '
      ENDIF
C
C ... Namelist namzdf : vertical diffusion
C
      avm0  = 1.e-4
      avt0  = 1.e-5
      navmt = 3
      avevd = 1.e-4
      nnpc1 =  1
      nnpc2 = 10
      ntrbbl = 0
      atrbbl = 1000.
C
      READ  ( numnam, namzdf )
C
      IF(lwp) THEN
      WRITE(numout,*) 'namzdf'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' vertical eddy viscosity        avm0   = ',avm0
      WRITE(numout,*) ' vertical eddy diffusivity      avt0   = ',avt0
      WRITE(numout,*) ' number of time step            navmt  = ',navmt
      WRITE(numout,*) ' vertical coefficient for evd   avevd  = ',avevd
      WRITE(numout,*) ' npc scheme frequency           nnpc1  = ',nnpc1
      WRITE(numout,*) ' npc scheme print frequency     nnpc2  = ',nnpc2
      WRITE(numout,*) ' bottom boundary layer flag     ntrbbl = ',ntrbbl
      WRITE(numout,*) ' bottom boundary layer coef.    atrbbl = ',atrbbl
      WRITE(numout,*) ' '
      ENDIF
C
C ... Namelist namric : richardson number dependent vertical diffusion
C
      avmri = 100.e-4
      alp   = 5.
      nric  = 2
C                   coeff ajustement de la parametrisation
C
      READ  ( numnam, namric )
C
#if defined key_zdfrichardson
      IF(lwp) THEN
      WRITE(numout,*) 'namric'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' maximum vertical viscosity     avmri  = ',avmri
      WRITE(numout,*) ' coefficient                    alp    = ',alp 
      WRITE(numout,*) ' coefficient                    nric   = ',nric
      WRITE(numout,*) ' '
      ENDIF
#endif
C
C ... Namelist namtke : turbulent eddy kinetic dependent
C                       vertical diffusion
C
      ediff = 0.1
      ediss = 0.7
      ebb   = 3.75
      efave = 1.
      emin  = 0.7071e-6
      emin0 = 1.e-4
      nitke = 50
      nmxl  = 2
      npdl  = 2
C
      READ  ( numnam, namtke )
C
#if defined key_zdftke
      IF(lwp) THEN
      WRITE(numout,*) 'namtke'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' coef. to compute avt           ediff  = ',ediff
      WRITE(numout,*) ' Kolmogoroff dissipation coef.  ediss  = ',ediss 
      WRITE(numout,*) ' tke surface input coef.        ebb    = ',ebb
      WRITE(numout,*) ' tke diffusion coef.            efave  = ',efave
      WRITE(numout,*) ' minimum value of tke           emin   = ',emin
      WRITE(numout,*) ' surface minimum value of tke   emin0  = ',emin0
      WRITE(numout,*) ' number of restart iter loops   nitke  = ',nitke
      WRITE(numout,*) ' mixing length type             nmxl   = ',nmxl
      WRITE(numout,*) ' prandl number flag             npdl   = ',npdl
      WRITE(numout,*) ' '
      ENDIF
#endif
C
C ... Namelist namddm : double diffusive mixing
C
      avts = 1.e-4
      hsbfr = 1.6
C
      READ  ( numnam, namddm )
C
#if defined key_ddmixing
      IF(lwp) THEN
      WRITE(numout,*) 'namddm'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' maximum avs for dd mixing      avts   = ',avts
      WRITE(numout,*) ' heat/salt buoyancy flux ratio  hsbfr  = ',hsbfr 
      WRITE(numout,*) ' '
      ENDIF
#endif
C
C ... Namelist nammbc : lateral and bottom momentum boundary condition
C
      shlat  = 2.
      nbotfr = 0 
      bfri1  = 4.e-4 
      bfri2  = 1.e-3 
      bfeb2  = 2.5e-3 
C
      READ  ( numnam, nammbc )
C
      IF(lwp) THEN
      WRITE(numout,*) 'nammbc'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' strength of lateral friction   shlat  = ',shlat
      WRITE(numout,*) ' type of bottom friction        nbotfr = ',nbotfr
      WRITE(numout,*) ' linear bottom friction coef.   bfri1  = ',bfri1
      WRITE(numout,*) ' nonlinear bottom drag coef.    bfri2  = ',bfri2
      WRITE(numout,*) ' bottom tke                     bfeb2  = ',bfeb2
      WRITE(numout,*) ' '
      ENDIF
C
C ... Namelist namqsr : penetrative solar radiation parameters
C
      rabs = 0.58
      xsi1 = 0.35
      xsi2 = 23.0
C
      READ  ( numnam, namqsr )
C
      IF(lwp) THEN
      WRITE(numout,*) 'namqsr'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' fraction associated with xsi   rabs   = ',rabs
      WRITE(numout,*) ' first depth of extinction      xsi1   = ',xsi1
      WRITE(numout,*) ' second depth of extinction     xsi2   = ',xsi2
      WRITE(numout,*) ' '
      ENDIF
C
C ... Namelist namtdp : temperature and salinity restoring term
C
      ndmp   =   -1
      ndmpf  =    2
      nmldmp =    0
      sdmp   =  50.
      bdmp   = 360.
      hdmp   = 800.
C
      READ  ( numnam, namtdp )
#if defined key_tradmp
#    if defined key_antarctic || defined key_arctic
C    restoring to climatology at closed north or south boundaries
          nmldmp = 0
#    endif
C
      IF(lwp) THEN
      WRITE(numout,*) 'namtdp'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' T and S damping option         ndmp   = ',ndmp
      WRITE(numout,*) ' create a damping.coeff file    ndmpf  = ',ndmpf
      WRITE(numout,*) ' mixed layer damping option     nmldmp = ',nmldmp
      WRITE(numout,*) ' surface time scale (days)      sdmp   = ',sdmp 
      WRITE(numout,*) ' bottom time scale (days)       bdmp   = ',bdmp 
      WRITE(numout,*) ' depth of transition (meters)   hdmp   = ',hdmp
      WRITE(numout,*) ' '
      ENDIF
#endif
C
C ... namelist nameos : ocean physical parameters
C
      neos   =      0
      rau0   =  1020.
      ralpha =  2.e-4
      rbeta  =  0.029
      rcp    =  4.e+3
C
      READ  ( numnam, nameos )
C
      ro0cpr = 1. / ( rau0 * rcp )
C
      IF(lwp) THEN
      WRITE(numout,*) 'nameos'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' flag for eq. of state and N^2  neos   = ',neos
      WRITE(numout,*) ' volumic mass of reference      rau0   = ',rau0
      WRITE(numout,*) ' thermal exp. coef. (linear)    ralpha = ',ralpha
      WRITE(numout,*) ' saline exp. coef. (linear)     rbeta  = ',rbeta
      WRITE(numout,*) ' ocean specific heat            rcp    = ',rcp
      WRITE(numout,*) '          1. / ( rau0 * rcp ) = ro0cpr = ',ro0cpr
      WRITE(numout,*) ' '
      ENDIF
C
C ... Namelist namsol : elliptic solver / islands / free surface
C
      nsolv  = 1
      nmax   = 800
      eps    = .01 
      sor    = 1.76
      epsisl = 1.e-10
      nmisl  = 4000
      rnu    = 1.
C
      READ  ( numnam, namsol )
C
#if defined key_feti
C   ... FETI algorithm, we force nsolv at 3
      nsolv=3
#endif
C
      IF(lwp) THEN
      WRITE(numout,*) 'namsol'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' type of elliptic solver        nsolv  = ',nsolv
      WRITE(numout,*) ' maximum iterations for solver  nmax   = ',nmax
      WRITE(numout,*) ' absolute precision of solver   eps    = ',eps
      WRITE(numout,*) ' optimal coefficient of sor     sor    = ',sor
#if defined key_islands
      WRITE(numout,*) ' absolute precision stream fct  epsisl = ',epsisl
      WRITE(numout,*) ' maximum pcg iterations island  nmisl  = ',nmisl
#endif
      WRITE(numout,*) ' free surface parameter         rnu    = ',rnu
      WRITE(numout,*) ' '
      ENDIF
C
C ... namelist namdia : diagnostic
C
      ntrd   = 10
      ngap   = 10
      nprg   = 10
      nfznl  = 10
      nctls  = 0
C
      READ  ( numnam, namdia )
C
      IF(lwp) THEN
      WRITE(numout,*) 'namdia'
      WRITE(numout,*) ' '
      WRITE(numout,*) ' time step frequency trend      ntrd   = ',ntrd
      WRITE(numout,*) ' frequency of zonal flx         nfznl  = ',nfznl
      WRITE(numout,*) ' time step frequency for gap     ngap  = ',ngap
      WRITE(numout,*) ' switch for control print gap    nprg  = ',nprg
      WRITE(numout,*) ' control surface for trends      nctls = ',nctls
      WRITE(numout,*) ' '
      ENDIF
C
C
C ... Namelist namspr : surface pressure
C
      nmaxp= 2000
      epsp = 1.e-6
      niterp = 16
C
      READ(numnam,namspr)
C
#if defined key_diaspr
      IF(lwp) THEN
          WRITE(numout,*) 'namspr'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' maximum iterations for solver  nmaxp  = ',
     $        nmaxp
          WRITE(numout,*) ' absolute precision of solver   epsp   = ',
     $        epsp
          WRITE(numout,*) ' number of solver iterations    niterp = ',
     $        niterp
          WRITE(numout,*) ' frequeny of averaged output    nwrite = ',
     $        nwrite
          WRITE(numout,*) ' '
      ENDIF
#endif
C
#if defined key_coupled
C ... Namelist namcpl : coupling mode and frequency
C
      nexco = 24
c
c     -Define exchange TYPE
c     -Define the model name
c     -Define the coupler namec
      cchan='SIPC'
      nmodcpl = 2
      cplmodnam = 'opa.xx'       ! as $NBMODEL in namcouple
      cploasis = 'Oasis'        !  as in coupler
c
c     -Define symbolic name for fields exchanged from ocean to coupler,
c         must be the same as (1) of the field  definition in namcouple:
      nfldo2c=3
      cpl_writ(1)='SOSSTSST'
      cpl_writ(2)='SOICECOV'
      cpl_writ(3)='SOALBEDO'
c
c     -Define files name for fields exchanged from ocean to coupler,
c         must be the same as (6) of the field  definition in namcouple:
      nflxc2o=9
      cpl_readflx(1)='SONSHLDO' ! non solar heat flux (positif vers l'ocean)
      cpl_readflx(2)='SOSHFLDO' ! solar flux
      cpl_readflx(3)='SOLATHSU' ! evaporation
      cpl_readflx(4)='SOTOLPSU' ! liq precip
      cpl_readflx(5)='SOTOSPSU' ! solid precip
      cpl_readflx(6)='SORUNOFF' ! run-off
      cpl_readflx(7)='SOCALVIN' ! calving
      cpl_readflx(8)='SODFLXDT' ! non solar flux derivative
      cpl_readflx(9)='SOALBICE' ! surface albedo
      ntauc2o=4
      cpl_readtau(1)='SOZOTAUX' ! zonal wind stress ugrid
      cpl_readtau(2)='SOMETAUY' ! meridional wind stress vgrid
      cpl_readtau(3)='SOZOTAUV' ! zonal wind stress vgrid
      cpl_readtau(4)='SOMETAUU' ! meridional wind stress ugrid
c
c     -Define files name for fields exchanged from ocean to coupler,
c         must be the same as (6) of the field  definition in namcouple:
      cpl_f_writ(1)='oce2oas'
      cpl_f_writ(2)='oce2oas'
      cpl_f_writ(3)='oce2oas'
c
c     -Define files name for fields exchanged from coupler to ocean
c         must be the same as (7) of the field  definition in namcouple:
c     not used for SIPC and CLIM techniques
C
      READ  ( numnam, namcpl )
#endif
C
#if defined key_coupled || defined key_ice_igloo || defined key_bulk
      IF(lwp) THEN
          WRITE(numout,*) 'namcpl'
          WRITE(numout,*) ' '
          WRITE(numout,*) ' Coupling exchange frequency    nexco  = '
     $        ,nexco
          WRITE(numout,*) ' Coupling exchange technique    cchan  = '
     $        ,cchan
          WRITE(numout,*) ' Mode Coupling technique      nmodcpl  = '
     $        ,nmodcpl
          WRITE(numout,*) ' Define the model name      cplmodnam  = '
     $        ,cplmodnam
          WRITE(numout,*) ' Define the coupler name      cploasis = '
     $        ,cploasis
          WRITE(numout,*) ' Fields number ocean to coupler nfldo2c= '
     $        ,nfldo2c
          WRITE(numout,*) ' Flux fields coupler to ocean nflxc2o = '
     $        ,nflxc2o
          WRITE(numout,*) ' Stress fields coupler to ocean ntauc2o= '
     $        ,ntauc2o
          IF ( cchan .EQ. 'PIPE' .OR.  cchan .EQ. 'pipe' ) THEN
              cchan='PIPE'
              WRITE(numout,*)
     $            '(communication between models made by pipes)'
          ELSEIF( cchan .EQ. 'CLIM' .OR. cchan .EQ. 'clim' ) THEN
              cchan='CLIM'
              WRITE(numout,*)
     $            '(communication between models made by CLIM-PVM)'
          ELSEIF( cchan .EQ. 'SIPC' .OR. cchan .EQ. 'sipc' ) THEN
              cchan='SIPC'
              WRITE(numout,*)
     $            '(communication between models made by the',
     $            'Share Memory Segment and Semaphore)'
          ELSE
              WRITE(numout,*) 'technic not yet implemented ',cchan
              STOP 'in parlec'
          ENDIF
          DO jf = 1, nflxc2o
            WRITE(numout,*) 'file to receive field number = ',jf,'  ',
     $          cpl_f_readflx(jf) 
          END DO
          DO jf = 1, ntauc2o
            WRITE(numout,*) 'file to receive field number = ',jf,'  ',
     $          cpl_f_readtau(jf) 
          END DO
          DO jf = 1, nfldo2c
            WRITE(numout,*) 'file to send field number = ',jf,'  ',
     $          cpl_f_writ(jf)
          END DO 
          WRITE(numout,*) ' fields received from coupler'
          DO jf = 1, nflxc2o
            WRITE(numout,*) 'symbolic name for field number = ',jf,'  ',
     $          cpl_readflx(jf) 
          END DO
          DO jf = 1, ntauc2o
            WRITE(numout,*) 'symbolic name for field number = ',jf,'  ',
     $          cpl_readtau(jf) 
          END DO
          WRITE(numout,*) ' fields send to coupler'
          DO jf = 1, nfldo2c
            WRITE(numout,*) 'symbolic name for field number = ',jf,'  ',
     $          cpl_writ(jf)
          END DO   
      ENDIF
#else
C     no coupling
#endif
C
#if defined key_eastobc || defined key_westobc || defined key_northobc || defined key_southobc
C
C ... Namelist namobc : open boundaries
C
C ... default values
      nieob  = jpiglo-1
      niwob  = 1    
      njnob  = jpjglo-1
      njsob  = 1    
      rdpein = 1.
      rdpwin = 1.
      rdpnin = 1.
      rdpsin = 1.
      rdpeob = 15.
      rdpwob = 15.
      rdpnob = 15.
      rdpsob = 15.
      zbsic1 = 0.e0
      zbsic2 = 0.e0
      zbsic3 = 0.e0
C
C ... lecture of namobc
      REWIND( numnam )
      READ  ( numnam, namobc )
C
      bsfic0(1) = zbsic1
      bsfic(2) = zbsic2
      bsfic(3) = zbsic3
C
C ... number of open boudaries and open boundary indicators
C
#if ! defined key_eastobc
      nieob  = 0    
#endif
#if ! defined key_westobc
      niwob  = 0    
#endif
#if ! defined key_northobc
      njnob  = 0
#endif
#if ! defined key_southobc
      njsob  = 0
#endif
      nbobc = min0( 1, nieob ) + min0( 1, niwob )
     $      + min0( 1, njnob ) + min0( 1, njsob )
C
      IF(lwp)WRITE(numout,*) ' Number of open boundaries    nbobc = ',
     $                       nbobc
      IF(lwp)WRITE(numout,*)
      IF ( nbobc.NE.0 .AND. jperio.NE.0 ) THEN
          IF(lwp)WRITE(numout,*)
          IF(lwp)WRITE(numout,*) ' E R R O R : Cyclic or symmetric,',
     $                           ' and open boundary condition are not',
     $                           ' compatible'
          IF(lwp)WRITE(numout,*) ' ========== '
          IF(lwp)WRITE(numout,*)
          STOP 'parlec'
      ENDIF
C
C ... control prints
C
      IF(lwp)WRITE(numout,*) 'namobc'
      IF(lwp)WRITE(numout,*) ' '
#ifdef key_eastobc
      IF(lwp) THEN
      WRITE(numout,*) ' east open boundary :'
      WRITE(numout,*) '     i index                    nieob  = ',nieob
      WRITE(numout,*) '     damping time scale (days)  rdpeob = ',rdpeob
      WRITE(numout,*) '     damping time scale (days)  rdpein = ',rdpein
      ENDIF
#endif
C
#ifdef key_westobc
      IF(lwp) THEN
      WRITE(numout,*) ' west open boundary :'
      WRITE(numout,*) '     i index                    niwob  = ',niwob
      WRITE(numout,*) '     damping time scale (days)  rdpwob = ',rdpwob
      WRITE(numout,*) '     damping time scale (days)  rdpwin = ',rdpwin
      ENDIF
#endif
C
#ifdef key_northobc
      IF(lwp) THEN
      WRITE(numout,*) ' north open boundary :'
      WRITE(numout,*) '     j index                    njnob  = ',njnob
      WRITE(numout,*) '     damping time scale (days)  rdpnob = ',rdpnob
      WRITE(numout,*) '     damping time scale (days)  rdpnin = ',rdpnin
      ENDIF
#endif
C
#ifdef key_southobc
      IF(lwp) THEN
      WRITE(numout,*) ' south open boundary :'
      WRITE(numout,*) '     j index                    njsob  = ',njsob
      WRITE(numout,*) '     damping time scale (days)  rdpsob = ',rdpsob
      WRITE(numout,*) '     damping time scale (days)  rdpsin = ',rdpsin
      WRITE(numout,*) ' '
      ENDIF
#endif
#endif
C
      RETURN
      END
