CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/rstwri.F,v 1.1.1.1.6.3 2002/02/04 13:45:31 maisonna Exp $
CDIR$ LIST
      SUBROUTINE rstwri(kt)
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE RSTWRI
CCC                     ******************
CCC
CCC  PURPOSE :
CCC  ---------
CCC     Write restart fields in numwrs
CCC
CC   METHOD :
CC   -------
CC
CC	numwrs file:
CC	each nstock time step , save fields which are necessary for
CC	restart
CC
CC
CC   INPUT :
CC   -----
CC      argument
CC              kt              : time step
CC      common
CC            /COMNOW/          : present fields (now)
CC
CC   OUTPUT :
CC   ------
CC      file
CC		numwrs		: standard restart fields output
CC
CC
CC   WORKSPACE :
CC   ---------
CC      ino0,it0,ipcg0,isor0,itke0
CC
CC   MODIFICATIONS:
CC   --------------
CC      original : 91-03 ()
CC      addition : 91-11 (G. Madec)
CC      addition : 92-06 (M. Imbard) correction restart file
CC      addition : 92-07 (M. Imbard) split into diawri and rstwri
CC               : 98-02 (M. Guyon) FETI method
CC      addition : 98-05 (G. Roullet) free surface
CC      addition : 99-11 (M. Imbard) NetCDF FORMAT with ioipsl
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
#if defined key_mpp || defined key_fdir
c no ioipsl
#include "rstwri.mpp.h"
#    else
CDIR$ NOLIST
      USE ioipsl
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER kt
      INTEGER ino0, it0, ipcg0, isor0, itke0
      INTEGER ic, jc
      INTEGER iyear, imonth, iday, iy, itime
      REAL zsec, zdate0, zinfo(6)
      CHARACTER*50 clname, cln
      LOGICAL clbon
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (15/11/96)
CCC---------------------------------------------------------------------
C
C
      IF( (mod(kt,nstock).eq.0) .OR. (kt.eq.nitend) ) THEN
C
C 0. Initializations
C ------------------
C
          IF(lwp) THEN
              WRITE(numout,*) ' '
              WRITE(numout,*) ' rstwri: output done in numwrs = ',
     $            numwrs,' at it= ',kt,' date= ',ndastp
              WRITE(numout,*) ' -------'
          ENDIF
C
          ino0 =no
          it0  =kt
          ipcg0=0
          isor0=0
          itke0=0
          isor0=nsolv-1
          ipcg0=2-nsolv
#ifdef key_zdftke
          itke0=1
#endif
C FETI method
          IF (nsolv .EQ. 3) THEN 
              isor0 = 2
              ipcg0 = 2
          ENDIF
C
C 1. Write in numwrs
C ------------------
C
C ... first
C
          INQUIRE (FILE=crestart,EXIST=clbon)
          IF(clbon) THEN
              OPEN(UNIT=numwrs,FILE=crestart,STATUS='old')
              CLOSE(numwrs,STATUS='delete')
          ENDIF 
          iyear = ndastp/10000
          imonth = ndastp/100 - iyear*100
          iday = ndastp - imonth*100 - iyear*10000
          iyear = ndastp/10000
          zsec=0.
C          iy=iyear-(iyear/100)*100
          iy=iyear
          ic=1
          DO jc=1,16
            IF(cexper(jc:jc).ne.' ') ic=jc
          END DO
          WRITE(cln,'("_",i4.4,i2.2,i2.2,"_restart")') iy,imonth,iday
          clname=cexper(1:ic)//cln
          ic=1
          DO jc=1,48
            IF(clname(jc:jc).ne.' ') ic=jc
          END DO
          crestart=clname(1:ic)//".nc"
          itime=0
          CALL ymds2ju(iyear,imonth,iday,zsec,zdate0)
          CALL restini('NONE',jpi,jpj,glamt,gphit,jpk,gdept,clname
     $        ,itime,zdate0,rdt*nstock,numwrs)
          zinfo(1)=FLOAT(ino0)
          zinfo(2)=FLOAT(it0)
          zinfo(3)=FLOAT(ipcg0)
          zinfo(4)=FLOAT(isor0)
          zinfo(5)=FLOAT(itke0)
          zinfo(6)=FLOAT(ndastp)
          CALL restput(numwrs,'info',1,1,6,0,zinfo)
C
C ... prognostic variables
C
          CALL restput(numwrs,'ub',jpi,jpj,jpk,0,ub)
          CALL restput(numwrs,'vb',jpi,jpj,jpk,0,vb)
          CALL restput(numwrs,'tb',jpi,jpj,jpk,0,tb)
          CALL restput(numwrs,'sb',jpi,jpj,jpk,0,sb)
          CALL restput(numwrs,'rotb',jpi,jpj,jpk,0,rotb)
          CALL restput(numwrs,'hdivb',jpi,jpj,jpk,0,hdivb)
          CALL restput(numwrs,'un',jpi,jpj,jpk,0,un)
          CALL restput(numwrs,'vn',jpi,jpj,jpk,0,vn)
          CALL restput(numwrs,'tn',jpi,jpj,jpk,0,tn)
          CALL restput(numwrs,'sn',jpi,jpj,jpk,0,sn)
          CALL restput(numwrs,'rotn',jpi,jpj,jpk,0,rotn)
          CALL restput(numwrs,'hdivn',jpi,jpj,jpk,0,hdivn)
#if defined key_ice_lln
          CALL restput(numwrs,'tn_ice' ,jpi,jpj,1,0,tn_ice)
          CALL restput(numwrs,'alb_ice',jpi,jpj,1,0,alb_ice)
#if defined key_coupled
          CALL restput(numwrs,'sstmoyb',jpi,jpj,1,0,sstmoy(:,:,1))
          CALL restput(numwrs,'sstmoyn',jpi,jpj,1,0,sstmoy(:,:,2))
#endif
#endif
C
C ... Read elliptic solver arrays
C
          CALL restput(numwrs,'gcx',jpi,jpj,1,0,gcx)
          CALL restput(numwrs,'gcxb',jpi,jpj,1,0,gcxb)
C
#ifdef key_freesurf_cstvol
C
C ... free surface formulation (eta)
C
          CALL restput(numwrs,'etab',jpi,jpj,1,0,etab)
          CALL restput(numwrs,'etan',jpi,jpj,1,0,etan)
#  else
C
C ... Rigid-lid formulation (bsf)
C
          CALL restput(numwrs,'bsfb',jpi,jpj,1,0,bsfb)
          CALL restput(numwrs,'bsfn',jpi,jpj,1,0,bsfn)
          CALL restput(numwrs,'bsfd',jpi,jpj,1,0,bsfd)
#endif
C
C ... tke arrays
C
#ifdef key_zdftke
          CALL restput(numwrs,'en',jpi,jpj,jpk,0,en)
#endif
C
C ... Louvain La Neuve Sea Ice Model
#if defined key_ice_lln
          sbcocn(1,1,1)=FLOAT(nfice)
          CALL restput(numwrs,'sbcocn',jpi,jpj,10,0,sbcocn)
#endif
C
          CALL restclo(numwrs)
C
      ENDIF
C
#endif
C
      RETURN
      END
