CCC $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_ORCA/stpcmo.F,v 1.1.1.1.6.3 2002/02/04 13:45:31 maisonna Exp $
CDIR$ LIST
      SUBROUTINE stpcmo ( kt )
CCC---------------------------------------------------------------------
CCC
CCC                       ROUTINE stpcmo
CCC                     ******************
CCC
CCC  Purpose :
CCC  --------
CCC             *****************
CCC             * OASIS routine *
CCC             * ------------- *
CCC             *****************
CCC   At each coupling time-step,this routine sends fields like sst or
CCC   ice cover to the coupler.
CCC   At each time-step computes time average values 
CCC   Specific treatment for the last time-step
CCC
CC   Method :
CC   -------
CC    2 types :
CC    a) Use named pipes(FIFO) to exchange process identifiers
CC      between the 3 programs - DISABLED
CC    b) USE a messag passing method with PVM language (CLIM)
CC    c) USE SVIPC method
CC
CC   Input :
CC   ------
CC      argument
CC              kt   : time step
CC
CC   Output :			: no
CC   -------
CC
CC   Modifications :
CC   --------------
CC       original  : 92-09 (Laurent Terray)
CC       modified  : 96-07 (Laurent Terray) : OASIS version 2
CC       modified  : 96-11 (Eric Guilyardi) : run-off + Taux,Tauy x2
CC       modified  : 98-04 (M.A Foujols, S. Valcke, M. Imbard) OASIS2.2
CC       adapted   : 01-06 (S. Valcke, E. Maisonnave) Predicate coupling
CC----------------------------------------------------------------------
CC parameters and commons
CC ======================
CCC TEMPORARY IOIPSL OUTPUTS START
C      USE ioipsl
CCC TEMPORARY IOIPSL OUTPUTS END
CDIR$ NOLIST
#include "parameter.h"
#include "common.h"
CDIR$ LIST
CC----------------------------------------------------------------------
CC local declarations
CC ==================
      INTEGER kt
#ifdef key_coupled
      INTEGER ji, jj, jn, jf
      INTEGER icstep, info, ierror, isize
      INTEGER iflmax, iunmax
      INTEGER ifile(jpmaxfld), ifield(jpmaxfld)
      CHARACTER*8 clfile(jpmaxfld) 
      LOGICAL llfind
      REAL zstoc(jpiglo,jpjglo),zieoc(jpiglo,jpjglo)
      REAL zalboc(jpiglo,jpjglo)
CCC TEMPORARY IOIPSL OUTPUTS START
C
C netcdf outputs
c 
C      CHARACTER*80 clcplsnam
C      INTEGER nhoridcs,nidcs,ndexcs(1)
C      SAVE nhoridcs,nidcs,ndexcs
C      LOGICAL, SAVE :: lfirsts=.true.
C      REAL zjulian,zsec
C      INTEGER iyear,imonth,iday
CCC TEMPORARY IOIPSL OUTPUTS END
C
C Additions for SVIPC
c
      INTEGER index
      INTEGER infos(3)
      CHARACTER*3 clmodinf       ! Header or not
      CHARACTER*3 cljobnam      ! experiment name
CC----------------------------------------------------------------------
CC statement functions
CC ===================
CDIR$ NOLIST
#include "stafun.h"
CDIR$ LIST
CCC---------------------------------------------------------------------
CCC  OPA8, LODYC (1997)
CCC---------------------------------------------------------------------
C
C coupled mode Ocean/Atmosphere
C
C 0. Initialization
C------------------
C
      isize=jpiglo*jpjglo
C
C ... First time step: ocean sst and ice sea-ice extend set to zero
      IF ( kt.EQ.nit000 ) THEN
          DO jj = 1, jpj
            DO ji = 1, jpi
              sstoc(ji,jj) = 0.e0
              sieoc(ji,jj) = 0.e0
              alboc(ji,jj) = 0.e0
            END DO
          END DO
CCC TEMPORARY IOIPSL OUTPUTS START
C
C initialisation for netcdf outputs
C 
C          ndexcs(:)=0
C          clcplsnam="cpl_oce_sst"
C
C Compute julian date from starting date of the run
C          iyear = ndastp/10000
C          imonth = ndastp/100 - iyear*100
C          iday = ndastp - imonth*100 - iyear*10000
C          iyear = ndastp/10000
C          zsec=0.
C          CALL ymds2ju(iyear,imonth,iday,zsec,zjulian)
C          CALL histbeg(clcplsnam, jpiglo,glamt,jpjglo,gphit,1,jpiglo,1
C     $        ,jpjglo,0,zjulian,rdt,nhoridcs,nidcs)
C no vertical axis
C          DO jf=1,nfldo2c
C            CALL histdef(nidcs, cpl_writ(jf),cpl_writ(jf),
C     $          "-",jpi, jpj, nhoridcs, 1, 1, 1, -99, 32, "inst", 
C     $          rdt,rdt)
C          END DO 
C          CALL histend(nidcs)
CCC TEMPORARY IOIPSL OUTPUTS END
      ENDIF
C
C 1. Cumulated sst and sea-ice extend
C------------------------------------
C
      DO jj = 1, jpj
        DO ji = 1, jpi
          sstoc(ji,jj) = sstoc(ji,jj) + (1.0-freeze(ji,jj))*
     $                   (tn(ji,jj,1)+rt0) + freeze(ji,jj)*
     $                   tn_ice(ji,jj)
          sieoc(ji,jj) = sieoc(ji,jj) + freeze(ji,jj)
#if defined key_ice_lln
          alboc(ji,jj) = alboc(ji,jj) + freeze(ji,jj)*
     $                    alb_ice(ji,jj) +  
     $                    0.065*(1-freeze(ji,jj))
#else
          alboc(ji,jj) = alboc(ji,jj) + freeze(ji,jj)*
     $                    0.8
#endif
        END DO
      END DO
C
C
C 2. Send coupling fields to OASIS
C---------------------------------
C
      IF ( MOD(kt,nexco).EQ.0 ) THEN
C
C 2.1 Average
C
C ... mean coupling fields
          DO jj = 1, jpjglo
            DO ji = 1, jpiglo
              zstoc(ji,jj) = 0.0
              zieoc(ji,jj) = 0.0
              zalboc(ji,jj) = 0.0
            END DO
          END DO
          DO jj = 1, nlcj
            DO ji = 1, nlci
              zstoc (mindi(ji),mindj(jj)) = sstoc(ji,jj) 
     $                 / float(nexco) * tmask(ji,jj,1)
              zieoc (mindi(ji),mindj(jj)) = sieoc(ji,jj) 
     $                 / float(nexco) * tmask(ji,jj,1)
              zalboc(mindi(ji),mindj(jj)) = alboc(ji,jj) 
     $                 / float(nexco) * tmask(ji,jj,1)
            END DO
          END DO
          icstep = kt - nit000 + 1
C
          WRITE(numout,*) ' '
          WRITE(numout,*) 'STEP: Send fields to CPL with kt= ', kt
          WRITE(numout,*) ' '
CCC TEMPORARY IOIPSL OUTPUTS START
C
C outputs
C
C          CALL histwrite(nidcs,cpl_writ(1),kt,zstoc,jpi*jpj,ndexcs)
C          CALL histwrite(nidcs,cpl_writ(2),kt,zieoc,jpi*jpj,ndexcs)
C          CALL histwrite(nidcs,cpl_writ(3),kt,zalboc,jpi*jpj,ndexcs)
C          CALL histsync(nidcs)
CCC TEMPORARY IOIPSL OUTPUTS END
C
C 2.2 Last time step (clim or pipe) or pipe mode
C 
          IF (kt .EQ. nitend .OR. cchan .EQ. 'PIPE') THEN 
CCC TEMPORARY IOIPSL OUTPUTS START
c
c finalize outputs
c
C              CALL histclo(nidcs)
CCC TEMPORARY IOIPSL OUTPUTS END
c
c WRITE fields for coupler with pipe technique or for last time step
c
c         initialisation
c
              iflmax=1
              iunmax=99
c keeps first file name
              clfile(iflmax)=cpl_f_writ(iflmax)
c keeps first file unit
              ifile(iflmax)=iunmax
c decrements file unit maximum
              iunmax=iunmax-1
c keeps file unit for field
              ifield(1)=ifile(iflmax)
c
c different files names counter
c
              DO jf= 2, nfldo2c
                llfind=.false.
                DO jn= 1, iflmax
                  IF (.not.llfind) THEN
                      IF (cpl_f_writ(jf).EQ.clfile(jn)) THEN
c keep file unit for field
                          ifield(jf)=ifile(jn)
                          llfind=.true.
                      END IF 
                  END IF 
                END DO 
                IF (.not.llfind) then
c increment the number of different files
                    iflmax=iflmax+1
c keep file name
                    clfile(iflmax)=cpl_f_writ(jf)
c keep file unit for file
                    ifile(iflmax)=iunmax
c keep file unit for field
                    ifield(jf)=ifile(iflmax)
c decrement unit maximum number from 99 to 98, ...
                    iunmax=iunmax-1
                END IF 
              END DO 
C          
              DO jn=1, iflmax 
                OPEN (ifile(jn), FILE=clfile(jn), FORM='UNFORMATTED')
              END DO 
C              
              DO jf=1, nfldo2c
                IF (jf.eq.1)
     $              CALL locwrite(cpl_writ(jf),zstoc, isize,
     $              ifield(jf), ierror, numout) 
                IF (jf.eq.2)
     $              CALL locwrite(cpl_writ(jf),zieoc, isize,
     $              ifield(jf), ierror, numout) 
                IF (jf.eq.3)
     $              CALL locwrite(cpl_writ(jf),zalboc, isize,
     $              ifield(jf), ierror, numout) 
              END DO 
C
C simulate a FLUSH
C
              DO jn=1, iflmax 
                CLOSE (ifile(jn))
              END DO 
C
C Clim mode
              IF(cchan.eq.'CLIM') THEN 
c
c inform PVM daemon, I have finished
c
                  CALL CLIM_Quit (CLIM_ContPvm, info)
                  IF (info .NE. CLIM_Ok) THEN
                      WRITE (6, *) 'An error occured while',
     $                    'leaving CLIM. Error = ',info
                  ENDIF
              END IF 
          END IF 
c
c IF last we have finished
c
          IF (kt .EQ. nitend) RETURN 
C
C 2.3 normal exchange
C
c SIPC mode
          IF(cchan.eq.'SIPC') THEN
c
c         Define IF a header must be encapsulated within the field brick :
              clmodinf = 'NOT'  ! as $MODINFO in namcouple  
c
c         IF clmodinf = 'YES', define encapsulated infos to be exchanged
c		  infos(1) = initial date
c		  infos(2) = timestep
c		  infos(3) = actual time
c
c         Writing of output field SST SOSSTSST
c
c         Index of SST in total number of fields jpfldo2a: 
              index = 1
c   
              CALL SIPC_Write_Model(index, isize, clmodinf, 
     $            cljobnam, infos, zstoc)
C
c
c         Writing of output field Sea-Ice SOICECOV 
c
c         Index of sea-ice in total number of fields jpfldo2a: 
              index = 2
c   
              CALL SIPC_Write_Model(index, isize, clmodinf, 
     $            cljobnam, infos, zieoc)
C
C
c
c         Writing of output field Albedo 
c
c         Index of sea-ice in total number of fields jpfldo2a: 
              index = 3
c   
              CALL SIPC_Write_Model(index, isize, clmodinf, 
     $            cljobnam, infos, zalboc)
C
c
c CLIM mode
          ELSE IF(cchan.eq.'CLIM') THEN
c
              DO jn=1, nfldo2c
            
                IF (jn.eq.1) CALL CLIM_Export(cpl_writ(jn), icstep,
     $                                        zstoc, info)
                IF (jn.eq.2) CALL CLIM_Export(cpl_writ(jn), icstep,
     $                                        zieoc, info)
                IF (jn.eq.3) CALL CLIM_Export(cpl_writ(jn), icstep,
     $                                        zalboc, info)
                IF (info .NE. CLIM_Ok) THEN
                    WRITE (numout,*) 'STEP : Pb giving',
     $                  cpl_writ(jn), ':',jn
                    WRITE (numout,*) ' at timestep = ', icstep,'kt = '
     $                  ,kt
                    WRITE (numout,*) 'Clim error code is = ',info
                    WRITE (numout,*) 'STOP in stpcpl '
                    CALL abort(' stpcpl ')
                ENDIF
              END DO 
          ENDIF 
C
C ... reset cumulative sst and sea-ice extend to zero
          DO jj = 1, jpj
            DO ji = 1, jpi
CEM On sauve sstoc dans sstmoy. Cette variable 
C   sera recuperee au pas de temps 
C   de couplage suivant dans flx.coupled.clio.h
C
              sstmoy(ji,jj,3)=zstoc(ji,jj)
              sstoc(ji,jj) = 0.0
              sieoc(ji,jj) = 0.0
              alboc(ji,jj) = 0.0
            END DO
          END DO
              WRITE (numout,*) ' sstmoy(ji,jj,3) initialisee '
      ELSE IF ( MOD(kt,nexco).EQ.1 .AND. kt.NE.nit000) THEN
          DO jj = 1, jpj
            DO ji = 1, jpi
              sstmoy(ji,jj,1)=sstmoy(ji,jj,2)
              sstmoy(ji,jj,2)=sstmoy(ji,jj,3)
            END DO
          END DO
C
              WRITE (numout,*) ' sstmoy(ji,jj,1 et 2) initialisees'
      ENDIF
C
#  else
C    No coupling
#endif
C
      RETURN
      END
